@@ -1,3 +1,5 @@
+#include "antprojectpart.h"
+
 #include <qapplication.h>
 #include <qfile.h>
 #include <qfileinfo.h>
@@ -30,7 +32,6 @@
 #include "classpathwidget.h"
 
 
-#include "antprojectpart.h"
 
 
 typedef KDevGenericFactory<AntProjectPart> AntProjectFactory;
@@ -431,7 +432,7 @@ void AntProjectPart::slotTargetMenuActivated(int id)
 
 void AntProjectPart::ant(const QString &target)
 {
-  QString cmd = "cd %0 && %1 ant %2 -buildfile %3 %4 %5";
+  QString cmd = "%0 cd %1 && ant %2 -buildfile %3 %4 %5";
 
   QString verb = "";
   switch (m_antOptions.m_verbosity)
@@ -457,7 +458,7 @@ void AntProjectPart::ant(const QString &target)
   if (!m_classPath.count() == 0)
     cp = "CLASSPATH="+m_classPath.join(":");
   
-  makeFrontend()->queueCommand(m_projectDirectory, cmd.arg(m_projectDirectory).arg(cp).arg(target).arg(m_antOptions.m_buildXML).arg(verb).arg(options));
+  makeFrontend()->queueCommand(m_projectDirectory, cmd.arg(cp).arg(m_projectDirectory).arg(target).arg(m_antOptions.m_buildXML).arg(verb).arg(options));
 }
 
 
