@@ -83,7 +83,7 @@ SubprojectOptionsDialog::SubprojectOptionsDialog(AutoProjectPart *part, AutoProj
     QCheckListItem *lastItem = 0;
     QStringList::ConstIterator it;
     for (it = l.begin(); it != l.end(); ++it) {
-	kdDebug(9013) << "----------> subproject = " << (*it) << endl;
+    kdDebug(9020) << "----------> subproject = " << (*it) << endl;
 	QString subProjectName = *it;
 
 	if( subProjectName.isEmpty() ){
@@ -227,7 +227,7 @@ void SubprojectOptionsDialog::storeConfig()
 void SubprojectOptionsDialog::cflagsClicked()
 {
     QString new_cflags = AutoProjectTool::execFlagsDialog(ccompiler, cflags_edit->text(), this);
-    if (!new_cflags.isNull())
+//    if (!new_cflags.isNull())
         cflags_edit->setText(new_cflags);
 }
 
@@ -235,7 +235,7 @@ void SubprojectOptionsDialog::cflagsClicked()
 void SubprojectOptionsDialog::cxxFlagsClicked()
 {
     QString new_cxxflags = AutoProjectTool::execFlagsDialog(cxxcompiler, cxxflags_edit->text(), this);
-    if (!new_cxxflags.isNull())
+//    if (!new_cxxflags.isNull())
         cxxflags_edit->setText(new_cxxflags);
 }
 
@@ -243,7 +243,7 @@ void SubprojectOptionsDialog::cxxFlagsClicked()
 void SubprojectOptionsDialog::fflagsClicked()
 {
     QString new_fflags = AutoProjectTool::execFlagsDialog(f77compiler, fflags_edit->text(), this);
-    if (!new_fflags.isNull())
+//    if (!new_fflags.isNull())
         fflags_edit->setText(new_fflags);
 }
 
