@@ -5,6 +5,8 @@
  *   cloudtemple@mksat.net                                                 *
  *   Copyright (C) 2003 by Thomas Hasart                                   *
  *   thasart@gmx.de                                                        *
+ *   Copyright (C) 2006 by Andreas Pakulat                                 *
+ *   apaku@gmx.de                                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,27 +28,142 @@
 #include <kurlrequester.h>
 #include <kdebug.h>
 #include <kiconloader.h>
+#include <klistview.h>
 
 #include <qdialog.h>
 #include <qpushbutton.h>
 #include <qbuttongroup.h>
 #include <qlistview.h>
+#include <qlabel.h>
 #include <iostream>
 #include <qregexp.h>
 #include <qvalidator.h>
 #include <qtabwidget.h>
 #include <pathutil.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
+#include <klocale.h>
 
-ProjectConfigurationDlg::ProjectConfigurationDlg(SubqmakeprojectItem *_item,QListView *_prjList,QWidget* parent, const char* name, bool modal, WFlags fl)
+// in kde 3.4 KStdGuiItem::browse()
+KGuiItem browse()
+{
+	KGuiItem returnItem;
+	returnItem.setText(i18n("Browse"));
+	returnItem.setIconName("browse");
+	returnItem.setToolTip(i18n("Open browser"));
+	returnItem.setWhatsThis(i18n("Opens a file browser for selection of files or directories"));
+	return returnItem;
+}
+
+// in kde 3.4 KStdGuiItem::up()
+KGuiItem up()
+{
+	KGuiItem returnItem;
+	returnItem.setText(i18n("Up"));
+	returnItem.setIconName("up");
+	returnItem.setToolTip(i18n("Move up"));
+	return returnItem;
+}
+// in kde 3.4 KStdGuiItem::down()
+KGuiItem down()
+{
+KGuiItem returnItem;
+	returnItem.setText(i18n("Down"));
+	returnItem.setIconName("down");
+	returnItem.setToolTip(i18n("Move down"));
+	return returnItem;
+}
+// in kde 3.4 KStdGuiItem::edit()
+KGuiItem edit()
+{
+	KGuiItem returnItem;
+	returnItem.setText(i18n("Edit"));
+	returnItem.setIconName("edit");
+	returnItem.setToolTip(i18n("Edit value"));
+	return returnItem;
+}
+
+// in kde 3.4 KStdGuiItem::remove()
+KGuiItem add()
+{
+	KGuiItem returnItem;
+	returnItem.setText(i18n("Add"));
+	returnItem.setIconName("add");
+	returnItem.setToolTip(i18n("Remove value"));
+	return returnItem;
+}
+
+// in kde 3.4 KStdGuiItem::add()
+KGuiItem remove()
+{
+	KGuiItem returnItem;
+	returnItem.setText(i18n("Remove"));
+	returnItem.setIconName("remove");
+	returnItem.setToolTip(i18n("Remove value"));
+	return returnItem;
+}
+
+ProjectConfigurationDlg::ProjectConfigurationDlg(SubqmakeprojectItem *_item,QListView *_prjList,bool isQt4Project,QWidget* parent, const char* name, bool modal, WFlags fl)
 : ProjectConfigurationDlgBase(parent,name,modal,fl)
 //=================================================
 {
+// Remove when we can depend on KDE 3.4
+/*
+    buttonOk->setGuiItem(KStdGuiItem::ok());
+  buttonCancel->setGuiItem(KStdGuiItem::cancel());
+  Browse->setGuiItem(browse());
+  insideIncMoveUpBtn->setGuiItem(up());
+  insideIncMoveDownBtn->setGuiItem(down());
+  outsideIncAddBtn->setGuiItem(add());
+  outsideIncRemoveBtn->setGuiItem(remove());
+  outsideIncEditBtn->setGuiItem(edit());
+  outsideIncMoveUpBtn->setGuiItem(up());
+  outsideIncMoveDownBtn->setGuiItem(down());
+  insideLibMoveUpBtn->setGuiItem(up());
+  insideLibMoveDownBtn->setGuiItem(down());
+  outsideLibAddBtn->setGuiItem(add());
+  outsideLibRemoveBtn->setGuiItem(remove());
+  outsideLibEditBtn->setGuiItem(edit());
+  outsideLibMoveUpBtn->setGuiItem(up());
+  outsideLibMoveDownBtn->setGuiItem(down());
+  outsideLibDirAddBtn->setGuiItem(add());
+  outsideLibDirRemoveBtn->setGuiItem(remove());
+  outsideLibDirEditBtn->setGuiItem(edit());
+  outsideLibDirMoveUpBtn->setGuiItem(up());
+  outsideLibDirMoveDownBtn->setGuiItem(down());
+  intMoveUp_button->setGuiItem(up());
+  intMoveDown_button->setGuiItem(down());
+  extAdd_button->setGuiItem(add());
+  extRemove_button->setGuiItem(remove());
+  extEdit_button->setGuiItem(edit());
+  extMoveUp_button->setGuiItem(up());
+  extMoveDown_button->setGuiItem(down());
+  buildmoveup_button->setGuiItem(up());
+  buildmovedown_button->setGuiItem(down());
+  varAdd_button->setGuiItem(add());
+  varRemove_button->setGuiItem(remove());
+  varEdit_button->setGuiItem(edit());
+  varMoveUp_button->setGuiItem(up());
+  varMoveDown_button->setGuiItem(down());
+  */
+      // End remove in kde 3.4
+
+  this->isQt4Project = isQt4Project;
   myProjectItem=_item;
   prjList=_prjList;
 //  m_projectConfiguration = conf;
   m_targetLibraryVersion->setValidator(new QRegExpValidator(
     QRegExp("\\d+(\\.\\d+)?(\\.\\d+)"), this));
-  UpdateControls();
+  updateControls();
+  if ( isQt4Project )
+  {
+    radioDebugReleaseMode->setEnabled( true );
+    checkBuildAll->setEnabled(true);
+    qt4Group->setEnabled( myProjectItem->configuration.m_requirements & QD_QT );
+    rccdir_url->setEnabled( true );
+    rccdir_label->setEnabled( true );
+  }
+
 }
 
 
@@ -84,37 +201,42 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
 {
   // Template
   myProjectItem->configuration.m_requirements = 0;
-
-  if (radioApplication->isChecked())
+  if( !myProjectItem->isScope )
   {
-    myProjectItem->configuration.m_template = QTMP_APPLICATION;
-    myProjectItem->setPixmap(0,SmallIcon("qmake_app"));
+	if (radioApplication->isChecked())
+	{
+		myProjectItem->configuration.m_template = QTMP_APPLICATION;
+		myProjectItem->setPixmap(0,SmallIcon("qmake_app"));
+	}
+	else if (radioLibrary->isChecked())
+	{
+		myProjectItem->configuration.m_template = QTMP_LIBRARY;
+		if (staticRadio->isOn())
+			myProjectItem->configuration.m_requirements += QD_STATIC;
+		else if (sharedRadio->isOn()){
+			myProjectItem->configuration.m_requirements += QD_SHARED;
+			myProjectItem->configuration.m_libraryversion = m_targetLibraryVersion->text();
+		}
+		if (checkPlugin->isOn())
+		myProjectItem->configuration.m_requirements += QD_PLUGIN;
+		if ( checkDesigner->isChecked() )
+			myProjectItem->configuration.m_requirements += QD_DESIGNER;
+		myProjectItem->setPixmap(0,SmallIcon("qmake_lib"));
+	}
+	else if (radioSubdirs->isChecked())
+	{
+	myProjectItem->configuration.m_template = QTMP_SUBDIRS;
+	myProjectItem->setPixmap(0,SmallIcon("qmake_sub"));
+	}
   }
-  else if (radioLibrary->isChecked())
-  {
-    myProjectItem->configuration.m_template = QTMP_LIBRARY;
-    if (staticRadio->isOn())
-      myProjectItem->configuration.m_requirements += QD_STATIC;
-    if (sharedRadio->isOn()){
-      myProjectItem->configuration.m_requirements += QD_SHARED;
-      myProjectItem->configuration.m_libraryversion = m_targetLibraryVersion->text();
-    }
-    if (pluginRadio->isOn())
-      myProjectItem->configuration.m_requirements += QD_PLUGIN;
-    myProjectItem->setPixmap(0,SmallIcon("qmake_lib"));
-  }
-  else if (radioSubdirs->isChecked())
-  {
-    myProjectItem->configuration.m_template = QTMP_SUBDIRS;
-    myProjectItem->setPixmap(0,SmallIcon("qmake_sub"));
-  }
-
   // Buildmode
   if (radioDebugMode->isChecked())
     myProjectItem->configuration.m_buildMode = QBM_DEBUG;
   if (radioReleaseMode->isChecked())
     myProjectItem->configuration.m_buildMode = QBM_RELEASE;
-
+  if ( radioDebugReleaseMode->isChecked() )
+    myProjectItem->configuration.m_buildMode = QBM_DEBUG_AND_RELEASE;
+  
   // requirements
   if (exceptionCheck->isChecked())
     myProjectItem->configuration.m_requirements += QD_EXCEPTIONS;
@@ -132,11 +254,57 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
     myProjectItem->configuration.m_requirements += QD_X11;
   if (checkOrdered->isChecked())
     myProjectItem->configuration.m_requirements += QD_ORDERED;
-
+  if (checkLibtool->isChecked())
+  {
+    myProjectItem->configuration.m_requirements += QD_LIBTOOL;
+  }
+  if( checkPkgconf->isChecked())
+  {
+    myProjectItem->configuration.m_requirements += QD_PKGCONF;
+  }
+  if (checkConsole->isChecked() )
+  {
+    myProjectItem->configuration.m_requirements += QD_CONSOLE;
+  }
+  if (checkPCH->isChecked() )
+    myProjectItem->configuration.m_requirements += QD_PCH;
   // Warnings
   myProjectItem->configuration.m_warnings = QWARN_OFF;
   if (checkWarning->isChecked())
     myProjectItem->configuration.m_warnings = QWARN_ON;
+ 
+  //Qt4 libs
+  if ( isQt4Project )
+  {
+    if ( checkTestlib->isChecked() )
+      myProjectItem->configuration.m_requirements += QD_TESTLIB;
+    if ( checkAssistant->isChecked() )
+      myProjectItem->configuration.m_requirements += QD_ASSISTANT;
+    if ( checkUiTools->isChecked() )
+      myProjectItem->configuration.m_requirements += QD_UITOOLS;
+    if ( checkQDBus->isChecked() )
+      myProjectItem->configuration.m_requirements += QD_DBUS;
+    if ( checkBuildAll->isChecked() )
+      myProjectItem->configuration.m_requirements += QD_BUILDALL;
+  
+    myProjectItem->configuration.m_qt4libs = 0;
+    if ( checkQt4Core->isChecked() )
+      myProjectItem->configuration.m_qt4libs += Q4L_CORE;
+    if ( checkQt4Gui->isChecked() )
+      myProjectItem->configuration.m_qt4libs += Q4L_GUI;
+    if ( checkQt4SQL->isChecked() )
+      myProjectItem->configuration.m_qt4libs += Q4L_SQL;
+    if ( checkQt4SVG->isChecked() )
+      myProjectItem->configuration.m_qt4libs += Q4L_SVG;
+    if ( checkQt4XML->isChecked() )
+      myProjectItem->configuration.m_qt4libs += Q4L_XML;
+    if ( checkQt4Network->isChecked() )
+      myProjectItem->configuration.m_qt4libs += Q4L_NETWORK;
+    if ( checkQt3Support->isChecked() )
+      myProjectItem->configuration.m_qt4libs += Q4L_QT3;
+    if ( checkQt4OpenGL->isChecked() )
+      myProjectItem->configuration.m_qt4libs += Q4L_OPENGL;
+  }
 
   myProjectItem->configuration.m_target = "";
 /*  if ((m_targetPath->text().simplifyWhiteSpace()!="" ||
@@ -293,48 +461,58 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
   myProjectItem->configuration.idl_compiler=idlCmdEdit->url();
   myProjectItem->configuration.idl_options=idlCmdOptionsEdit->text();
 
+  // custom vars
+  QListViewItem *item = customVariables->firstChild();
+  for( ; item; item = item->nextSibling() )
+	myProjectItem->configuration.m_variables[item->text(0)] = item->text(1);
+
   QDialog::accept();
 
+
 }
 
 
-void ProjectConfigurationDlg::UpdateControls()
+void ProjectConfigurationDlg::updateControls()
 //============================================
 {
   QRadioButton *activateRadiobutton=NULL;
   // Project template
   libGroup->setEnabled(false);
-  switch (myProjectItem->configuration.m_template)
+  if( !myProjectItem->isScope )
   {
-    case QTMP_APPLICATION:
-      activateRadiobutton = radioApplication;
-      break;
-    case QTMP_LIBRARY:
-      libGroup->setEnabled(true);
+	switch (myProjectItem->configuration.m_template)
+	{
+	case QTMP_APPLICATION:
+	activateRadiobutton = radioApplication;
+	if (myProjectItem->configuration.m_requirements & QD_CONSOLE )
+		checkConsole->setChecked(true);
+	break;
+	case QTMP_LIBRARY:
+	libGroup->setEnabled(true);
 
-      activateRadiobutton = radioLibrary;
-      staticRadio->setChecked(true); //default
-      if (myProjectItem->configuration.m_requirements & QD_STATIC){
-        staticRadio->setChecked(true);
-/*        libAddTab->setEnabled(false);
-        libPathTab->setEnabled(false);*/
-        libAddTab->setEnabled(true);
-        libPathTab->setEnabled(true);
-      }else{
-        libAddTab->setEnabled(true);
-        libPathTab->setEnabled(true);
-      }
-      if (myProjectItem->configuration.m_requirements & QD_SHARED){
-        sharedRadio->setChecked(true);
-        m_targetLibraryVersion->setText(myProjectItem->configuration.m_libraryversion);
-      }
+	activateRadiobutton = radioLibrary;
+	staticRadio->setChecked(true); //default
+	if (myProjectItem->configuration.m_requirements & QD_STATIC){
+		staticRadio->setChecked(true);
+	}
+	if (myProjectItem->configuration.m_requirements & QD_SHARED){
+		sharedRadio->setChecked(true);
+		m_targetLibraryVersion->setText(myProjectItem->configuration.m_libraryversion);
+	}
 
-      if (myProjectItem->configuration.m_requirements & QD_PLUGIN)
-        pluginRadio->setChecked(true);
-      break;
-    case QTMP_SUBDIRS:
-      activateRadiobutton = radioSubdirs;
-      break;
+	if (myProjectItem->configuration.m_requirements & QD_PLUGIN)
+		checkPlugin->setChecked(true);
+	if ( myProjectItem->configuration.m_requirements & QD_DESIGNER )
+		checkDesigner->setChecked( true );
+	if (myProjectItem->configuration.m_requirements & QD_LIBTOOL )
+		checkLibtool->setChecked(true);
+	if (myProjectItem->configuration.m_requirements & QD_PKGCONF )
+		checkPkgconf->setChecked(true);
+	break;
+	case QTMP_SUBDIRS:
+	activateRadiobutton = radioSubdirs;
+	break;
+	}
   }
   // Buildmode
   if (activateRadiobutton)
@@ -347,10 +525,13 @@ void ProjectConfigurationDlg::UpdateControls()
     case QBM_RELEASE:
       activateRadiobutton = radioReleaseMode;
       break;
+    case QBM_DEBUG_AND_RELEASE:
+      activateRadiobutton = radioDebugReleaseMode;
+      break;
   }
   if (activateRadiobutton)
     activateRadiobutton->setChecked(true);
-
+  
   // Requirements
   if (myProjectItem->configuration.m_requirements & QD_QT)
     checkQt->setChecked(true);
@@ -368,13 +549,51 @@ void ProjectConfigurationDlg::UpdateControls()
     stlCheck->setChecked(true);
   if (myProjectItem->configuration.m_requirements & QD_RTTI)
     rttiCheck->setChecked(true);
-
+  if (myProjectItem->configuration.m_requirements & QD_PCH)
+    checkPCH->setChecked(true);
   // Warnings
   if (myProjectItem->configuration.m_warnings == QWARN_ON)
   {
     checkWarning->setChecked(true);
   }
 
+  //Qt4 libs
+  if ( isQt4Project )
+  {
+
+    if ( myProjectItem->configuration.m_requirements & QD_ASSISTANT )
+      checkAssistant->setChecked( true );
+    if ( myProjectItem->configuration.m_requirements & QD_TESTLIB )
+      checkTestlib->setChecked( true );
+    if ( myProjectItem->configuration.m_requirements & QD_UITOOLS )
+      checkUiTools->setChecked( true );
+    if ( myProjectItem->configuration.m_requirements & QD_DBUS )
+      checkQDBus->setChecked( true );
+    if ( myProjectItem->configuration.m_requirements & QD_BUILDALL )
+      checkBuildAll->setChecked( true );
+    
+    if ( myProjectItem->configuration.m_qt4libs & Q4L_CORE )
+      checkQt4Core->setChecked( true );
+    else
+      checkQt4Core->setChecked( false );
+    if ( myProjectItem->configuration.m_qt4libs & Q4L_GUI )
+      checkQt4Gui->setChecked( true );
+    else
+      checkQt4Gui->setChecked( false );
+    if ( myProjectItem->configuration.m_qt4libs & Q4L_SQL )
+      checkQt4SQL->setChecked( true );
+    if ( myProjectItem->configuration.m_qt4libs & Q4L_XML )
+      checkQt4XML->setChecked( true );
+    if ( myProjectItem->configuration.m_qt4libs & Q4L_NETWORK )
+      checkQt4Network->setChecked( true );
+    if ( myProjectItem->configuration.m_qt4libs & Q4L_SVG )
+      checkQt4SVG->setChecked( true );
+    if ( myProjectItem->configuration.m_qt4libs & Q4L_OPENGL )
+      checkQt4OpenGL->setChecked( true );
+    if ( myProjectItem->configuration.m_qt4libs & Q4L_QT3 )
+      checkQt3Support->setChecked( true );
+  }
+
   //makefile
   makefile_url->setURL(myProjectItem->configuration.m_makefile);
 
@@ -392,11 +611,11 @@ void ProjectConfigurationDlg::UpdateControls()
 */
   //target.path = path
   //INSTALLS += target
-  if (myProjectItem->configuration.m_target_install == true) 
+  if (myProjectItem->configuration.m_target_install == true)
   {
     checkInstallTarget->setChecked(true);
     m_InstallTargetPath->setEnabled(true);
-  } 
+  }
   else
   {
     checkInstallTarget->setChecked(false);
@@ -404,8 +623,8 @@ void ProjectConfigurationDlg::UpdateControls()
   }
   m_InstallTargetPath->setText(myProjectItem->configuration.m_target_install_path);
 
-  
-  
+
+
   m_targetOutputFile->setText(myProjectItem->configuration.m_target);
   m_targetPath->setText(myProjectItem->configuration.m_destdir);
   clickSubdirsTemplate();
@@ -417,17 +636,23 @@ void ProjectConfigurationDlg::UpdateControls()
   if (myProjectItem->configuration.m_inheritconfig == false)
     checkDontInheritConfig->setChecked(true);
   else
-    checkDontInheritConfig->setChecked(false);    
-     
+    checkDontInheritConfig->setChecked(false);
+
   updateIncludeControl();
   updateLibaddControl();
   updateLibDirAddControl();
-  updateBuildOrderControl();  
+  updateBuildOrderControl();
   updateDependenciesControl();
 
   objdir_url->setURL(myProjectItem->configuration.m_objectpath);
   uidir_url->setURL(myProjectItem->configuration.m_uipath);
   mocdir_url->setURL(myProjectItem->configuration.m_mocpath);
+
+
+  customVariables->clear();
+  QMap<QString,QString>::Iterator idx = myProjectItem->configuration.m_variables.begin();
+  for( ; idx != myProjectItem->configuration.m_variables.end(); ++idx )
+  	new KListViewItem(customVariables,idx.key(),idx.data());
 }
 
 QPtrList <qProjectItem> ProjectConfigurationDlg::getAllProjects()
@@ -467,7 +692,7 @@ void ProjectConfigurationDlg::updateIncludeControl()
   QPtrList <qProjectItem> itemList=getAllProjects();
   qProjectItem *item=itemList.first();
 
-  
+
   while(item){
     if(item->type() == qProjectItem::Subproject)
     {
@@ -487,7 +712,9 @@ void ProjectConfigurationDlg::updateIncludeControl()
 
           for(;it!=incList.end();++it)
           {
-            if((*it).find(tmpInc)>=0){
+             // we need an exact, case sensitive match here
+            if ((*it).contains(tmpInc, true) && ((*it).length() == tmpInc.length())) 
+            {            
               incList.remove(it);
               newItem->setOn(true);
               it=incList.begin();
@@ -554,8 +781,6 @@ void ProjectConfigurationDlg::updateLibaddControl()
         }
     }
 
-  kdDebug()<< "itemlist count =" << itemList.count()<<endl;
-
   //add all other prj in itemList unchecked
   qProjectItem *item=itemList.first();
   while(item)
@@ -629,8 +854,6 @@ void ProjectConfigurationDlg::updateDependenciesControl( )
         }
     }
 
-  kdDebug()<< "itemlist count =" << itemList.count()<<endl;
-
   //add all other prj in itemList unchecked
   qProjectItem *item=itemList.first();
   while(item)
@@ -709,8 +932,7 @@ void ProjectConfigurationDlg::updateBuildOrderControl()
         item=itemList.next();;
       }
 
-  }else buildOrderTab->setEnabled(false);
-
+  }
 }
 
 void ProjectConfigurationDlg::updateLibDirAddControl()
@@ -723,7 +945,7 @@ void ProjectConfigurationDlg::updateLibDirAddControl()
   outsidelibdir_listview->setSorting(-1,false);
 
   qProjectItem *item=itemList.first();
-  
+
   while(item){
     if(item->type()==qProjectItem::Subproject)
     {
@@ -736,13 +958,12 @@ void ProjectConfigurationDlg::updateLibDirAddControl()
         {
           // create lib string
           QString tmpLibDir=sItem->getLibAddPath(myProjectItem->getDownDirs());
-          
+
           QStringList::Iterator it=libDirList.begin();
           for(;it!=libDirList.end();++it)
           {
 
             if((*it).find(tmpLibDir)>=0 && tmpLibDir!="" && !tmpLibDir.isEmpty()){
-              kdDebug()<<"remove from LIBDIR   "<<(*it).ascii()<<"   tmpLib="<<tmpLibDir.ascii()<<""<<endl;
               libDirList.remove(it);
               it=libDirList.begin();
             }
@@ -757,10 +978,9 @@ void ProjectConfigurationDlg::updateLibDirAddControl()
   QStringList::Iterator it1=libDirList.begin();
   for(;it1!=libDirList.end();++it1)
   {
-      kdDebug()<<"create LIBDIR item  "<<(*it1).ascii()<<endl;
       new QListViewItem(outsidelibdir_listview,outsidelibdir_listview->lastItem(),(*it1));
   }
-  
+
 }
 
 
@@ -776,15 +996,34 @@ void ProjectConfigurationDlg::slotStaticLibClicked(int)
     libAddTab->setEnabled(true);
     libPathTab->setEnabled(true);
   }*/
+  if ( staticRadio->isChecked() )
+  {
+    checkPlugin->setEnabled( false );
+    checkDesigner->setEnabled( false );
+  }
 }
 
+void ProjectConfigurationDlg::sharedLibChanged()
+{
+  if ( sharedRadio->isChecked() )
+  {
+    checkPlugin->setEnabled( true );
+    checkDesigner->setEnabled( checkPlugin->isChecked() );
+  }
+}
 
 void ProjectConfigurationDlg::templateLibraryClicked(int)
 {
   if (radioLibrary->isChecked())
   {
-    libGroup->setEnabled(true);
 //    staticRadio->setChecked(true);
+    TabBuild->setTabEnabled(custVarsTab, true);
+    TabBuild->setTabEnabled(depTab,true);
+    TabBuild->setTabEnabled(libAddTab,true);
+    TabBuild->setTabEnabled(incaddTab,true);
+    TabBuild->setTabEnabled(buildOptsTab,true);
+    TabBuild->setTabEnabled(configTab,true);
+    libGroup->setEnabled(true);
   } else {
     libGroup->setEnabled(false);
   }
@@ -793,22 +1032,25 @@ void ProjectConfigurationDlg::clickSubdirsTemplate()
 {
   if (radioSubdirs->isChecked())
   {
-    m_targetPath->setEnabled(false);
-    m_targetOutputFile->setEnabled(false);
-    Browse->setEnabled(false);
-    libGroup->setEnabled(false);
-    buildOrderTab->setEnabled(true);
-    corbaTab->setEnabled(false);
+    TabBuild->setTabEnabled(custVarsTab, true);
+    TabBuild->setTabEnabled(depTab,false);
+    TabBuild->setTabEnabled(libAddTab,false);
+    TabBuild->setTabEnabled(incaddTab,false);
+    TabBuild->setTabEnabled(buildOptsTab,false);
+    TabBuild->setTabEnabled(configTab,false);
   }
   else
   {
-    m_targetPath->setEnabled(true);
-    m_targetOutputFile->setEnabled(true);
-    Browse->setEnabled(true);
-    buildOrderTab->setEnabled(false);
+    TabBuild->setTabEnabled(custVarsTab, true);
+    TabBuild->setTabEnabled(depTab,true);
+    TabBuild->setTabEnabled(libAddTab,true);
+    TabBuild->setTabEnabled(incaddTab,true);
+    TabBuild->setTabEnabled(buildOptsTab,true);
+    TabBuild->setTabEnabled(configTab,true);
+
     if (radioLibrary->isChecked()) libGroup->setEnabled(true);
     else libGroup->setEnabled(false);
-    corbaTab->setEnabled(true);
+    //70corbaTab->setEnabled(true);
   }
 }
 
@@ -1163,3 +1405,87 @@ void ProjectConfigurationDlg::intMoveUp_button_clicked( )
     item->moveItem(intDeps_view->currentItem());
 }
 
+ void ProjectConfigurationDlg::addCustomValueClicked()
+{
+  QListViewItem *item = new QListViewItem(customVariables, i18n("Name"),i18n("Value"));
+  customVariables->setSelected(item,true);
+  newCustomVariableActive();
+  customVariableName->setEnabled(true);
+}
+ void ProjectConfigurationDlg::removeCustomValueClicked()
+{
+  QListViewItem *item = customVariables->currentItem();
+  if( item )
+  {
+    myProjectItem->configuration.m_variables.remove(item->text(0));
+    myProjectItem->configuration.m_removed_variables.append(item->text(0));
+    delete item;
+  }
+}
+ void ProjectConfigurationDlg::editCustomValueClicked()
+{
+  QListViewItem *item = customVariables->currentItem();
+  if(item)
+  {
+     item->setText(0,customVariableName->text());
+     item->setText(1,customVariableData->text());
+     
+     if(myProjectItem->configuration.m_removed_variables.contains(customVariableName->text()) != 0)
+	myProjectItem->configuration.m_removed_variables.remove(customVariableName->text());
+  }
+}
+ void ProjectConfigurationDlg::upCustomValueClicked()
+{
+  // custom vars
+  QListViewItem *item = customVariables->firstChild();
+  if (customVariables->currentItem() == item) {
+    KNotifyClient::beep();
+    return;
+  }
+  while (item->nextSibling() != customVariables->currentItem())
+    item = item->nextSibling();
+  item->moveItem(customVariables->currentItem());
+}
+
+ void ProjectConfigurationDlg::downCustomValueClicked()
+{
+  if (customVariables->currentItem() == 0 || customVariables->currentItem()->nextSibling() == 0) {
+    KNotifyClient::beep();
+    return;
+  }
+  customVariables->currentItem()->moveItem(customVariables->currentItem()->nextSibling());
+}
+
+void ProjectConfigurationDlg::newCustomVariableActive( )
+{
+  QListViewItem *item = customVariables->currentItem();
+  if(item)
+  {
+	customVariableName->setText(item->text(0));
+	customVariableData->setText(item->text(1));
+	customVariableName->setFocus();
+	customVariableName->setEnabled(false);
+  }
+}
+
+void ProjectConfigurationDlg::checkPluginChanged( )
+{
+  if ( checkPlugin->isChecked() && isQt4Project )
+  {
+    checkDesigner->setEnabled( true );
+  }else
+  {
+    checkDesigner->setEnabled( false );
+  }
+}
+
+void ProjectConfigurationDlg::qtRequirementChanged()
+{
+  if ( checkQt->isChecked() && isQt4Project)
+  {
+    qt4Group->setEnabled( true );
+  }else
+  {
+    qt4Group->setEnabled( false );
+  }
+}
