@@ -5,6 +5,8 @@
  *   cloudtemple@mksat.net                                                 *
  *   Copyright (C) 2003 by Thomas Hasart                                   *
  *   thasart@gmx.de                                                        *
+ *   Copyright (C) 2006 by Andreas Pakulat                                 *
+ *   apaku@gmx.de                                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +18,9 @@
 #ifndef PROJECTCONFIGURATIONDLG_H
 #define PROJECTCONFIGURATIONDLG_H
 
-enum QMakeBuildMode    {QBM_DEBUG,QBM_RELEASE};
+enum QMakeBuildMode    {QBM_DEBUG,
+			QBM_RELEASE,
+			QBM_DEBUG_AND_RELEASE};
 enum QMakeWarnings     {QWARN_ON,QWARN_OFF};
 enum QMakeDepends      {QD_QT=		1<<0,
 			QD_OPENGL=	1<<1,
@@ -25,17 +29,31 @@ enum QMakeDepends      {QD_QT=		1<<0,
 			QD_STATIC=	1<<4,
                         QD_SHARED=	1<<5,
 			QD_PLUGIN=	1<<6,
-			QD_EXCEPTIONS=	1<<8,
-			QD_STL=		1<<9,
-			QD_RTTI=	1<<10,
-			QD_ORDERED=	1<<11,
-			QD_LIBTOOL=	1<<12,
-			QD_PKGCONF=	1<<13,
-			QD_DLL=		1<<14,
-			QD_CONSOLE=	1<<15,
-			QD_PCH=		1<<16
+			QD_EXCEPTIONS=	1<<7,
+			QD_STL=		1<<8,
+			QD_RTTI=	1<<9,
+			QD_ORDERED=	1<<10,
+			QD_LIBTOOL=	1<<11,
+			QD_PKGCONF=	1<<12,
+			QD_CONSOLE=	1<<13,
+			QD_PCH=		1<<14,
+			QD_DESIGNER=	1<<15,
+			QD_TESTLIB=	1<<16,
+			QD_ASSISTANT=	1<<17,
+			QD_UITOOLS=	1<<18,
+			QD_DBUS=	1<<19,
+			QD_BUILDALL=	1<<20
 			};
 enum QMakeTemplate     {QTMP_APPLICATION,QTMP_LIBRARY,QTMP_SUBDIRS};
+enum QMakeQt4Libs      {Q4L_CORE=	1<<0,
+			Q4L_GUI=	1<<1,
+			Q4L_SQL=	1<<2,
+			Q4L_XML=	1<<3,
+			Q4L_NETWORK=	1<<4,
+			Q4L_OPENGL=	1<<5,
+			Q4L_SVG=	1<<6,
+			Q4L_QT3=	1<<7
+		       };
 #include "projectconfigurationdlgbase.h"
 #include "trollprojectwidget.h"
 
@@ -47,9 +65,9 @@ class qProjectItem;
 class ProjectConfigurationDlg : public ProjectConfigurationDlgBase
 {
 public:
-  ProjectConfigurationDlg(SubqmakeprojectItem * _item,QListView *_prjList,QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+  ProjectConfigurationDlg(SubqmakeprojectItem * _item,QListView *_prjList,bool isQt4Project, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
   ~ProjectConfigurationDlg();
-  void UpdateControls();
+  void updateControls();
 
 public slots:
 //  virtual void           radioLibrarytoggled(bool);
@@ -110,12 +128,15 @@ void updateLibDirAddControl();
 void updateBuildOrderControl();
 void updateDependenciesControl();
 
-
+void checkPluginChanged();
+void qtRequirementChanged();
+void sharedLibChanged();
 
 protected:
   QListView *prjList;
   SubqmakeprojectItem *myProjectItem;
   QPtrList <qProjectItem> getAllProjects();
+  bool isQt4Project;
   void getAllSubProjects(qProjectItem *item,QPtrList <qProjectItem> *itemList);
 
 
