@@ -47,6 +47,8 @@
 #include <qstyle.h>
 #include <qtimer.h>
 
+#include <klocale.h>
+
 QAction *ActionDrag::the_action = 0;
 
 ActionDrag::ActionDrag(QAction *action, QWidget *source)
@@ -344,10 +346,10 @@ void QDesignerToolBar::contextMenuEvent( QContextMenuEvent *e )
 {
     e->accept();
     QPopupMenu menu( 0 );
-    menu.insertItem( tr( "Delete Toolbar" ), 1 );
+    menu.insertItem( i18n( "Delete Toolbar" ), 1 );
     int res = menu.exec( e->globalPos() );
     if ( res != -1 ) {
-	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( tr( "Delete Toolbar '%1'" ).arg( name() ),
+	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n( "Delete Toolbar '%1'" ).arg( name() ),
 							      formWindow, 0, this );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -392,12 +394,12 @@ void QDesignerToolBar::buttonContextMenuEvent( QContextMenuEvent *e, QObject *o
     const int ID_DELTOOLBAR = 3;
     QMap<QWidget*, QAction*>::Iterator it = actionMap.find( (QWidget*)o );
     if ( it != actionMap.end() && ::qt_cast<QSeparatorAction*>(*it) )
-	menu.insertItem( tr( "Delete Separator" ), ID_DELETE );
+	menu.insertItem( i18n( "Delete Separator" ), ID_DELETE );
     else
-	menu.insertItem( tr( "Delete Item" ), ID_DELETE );
-    menu.insertItem( tr( "Insert Separator" ), ID_SEP );
+	menu.insertItem( i18n( "Delete Item" ), ID_DELETE );
+    menu.insertItem( i18n( "Insert Separator" ), ID_SEP );
     menu.insertSeparator();
-    menu.insertItem( tr( "Delete Toolbar" ), ID_DELTOOLBAR );
+    menu.insertItem( i18n( "Delete Toolbar" ), ID_DELTOOLBAR );
     int res = menu.exec( e->globalPos() );
     if ( res == ID_DELETE ) {
 	QMap<QWidget*, QAction*>::Iterator it = actionMap.find( (QWidget*)o );
@@ -406,7 +408,7 @@ void QDesignerToolBar::buttonContextMenuEvent( QContextMenuEvent *e, QObject *o
 	QAction *a = *it;
 	int index = actionList.find( a );
 	RemoveActionFromToolBarCommand *cmd = new RemoveActionFromToolBarCommand(
-	    tr( "Delete Action '%1' from Toolbar '%2'" ).
+	    i18n( "Delete Action '%1' From Toolbar '%2'" ).
 	    arg( a->name() ).arg( caption() ),
 	    formWindow, a, this, index );
 	formWindow->commandHistory()->addCommand( cmd );
@@ -421,13 +423,13 @@ void QDesignerToolBar::buttonContextMenuEvent( QContextMenuEvent *e, QObject *o
 	    index = 0;
 
 	AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand(
-	    tr( "Add Separator to Toolbar '%1'" ).
+	    i18n( "Add Separator to Toolbar '%1'" ).
 	    arg( a->name() ),
 	    formWindow, a, this, index );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
     } else if ( res == ID_DELTOOLBAR ) {
-	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( tr( "Delete Toolbar '%1'" ).arg( name() ),
+	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n( "Delete Toolbar '%1'" ).arg( name() ),
 							      formWindow, 0, this );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -461,7 +463,7 @@ void QDesignerToolBar::removeWidget( QWidget *w )
     QAction *a = *it;
     int index = actionList.find( a );
     RemoveActionFromToolBarCommand *cmd =
-	new RemoveActionFromToolBarCommand( tr( "Delete Action '%1' from Toolbar '%2'" ).
+	new RemoveActionFromToolBarCommand( i18n( "Delete Action '%1' From Toolbar '%2'" ).
 					    arg( a->name() ).arg( caption() ),
 					    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
@@ -484,7 +486,7 @@ void QDesignerToolBar::buttonMouseMoveEvent( QMouseEvent *e, QObject *o )
 	return;
     int index = actionList.find( a );
     RemoveActionFromToolBarCommand *cmd =
-	new RemoveActionFromToolBarCommand( tr( "Delete Action '%1' from Toolbar '%2'" ).
+	new RemoveActionFromToolBarCommand( i18n( "Delete Action '%1' From Toolbar '%2'" ).
 					    arg( a->name() ).arg( caption() ),
 					    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
@@ -501,7 +503,7 @@ void QDesignerToolBar::buttonMouseMoveEvent( QMouseEvent *e, QObject *o )
 	    formWindow->selectWidget( ( (QDesignerAction*)a )->widget(), FALSE );
     }
     if ( !drag->drag() ) {
-	AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( tr( "Add Action '%1' to Toolbar '%2'" ).
+	AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n( "Add Action '%1' to Toolbar '%2'" ).
 									arg( a->name() ).arg( caption() ),
 									formWindow, a, this, index );
 	formWindow->commandHistory()->addCommand( cmd );
@@ -561,14 +563,14 @@ void QDesignerToolBar::dropEvent( QDropEvent *e )
     }
 
     if ( actionList.findRef( a ) != -1 ) {
-	QMessageBox::warning( MainWindow::self, tr( "Insert/Move Action" ),
-			      tr( "Action '%1' has already been added to this toolbar.\n"
+	QMessageBox::warning( MainWindow::self, i18n( "Insert/Move Action" ),
+			      i18n( "Action '%1' has already been added to this toolbar.\n"
 				  "An Action may only occur once in a given toolbar." ).
 			      arg( a->name() ) );
 	return;
     }
 
-    AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( tr( "Add Action '%1' to Toolbar '%2'" ).
+    AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n( "Add Action '%1' to Toolbar '%2'" ).
 								    arg( a->name() ).arg( caption() ),
 								    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
@@ -694,7 +696,7 @@ void QDesignerToolBar::doInsertWidget( const QPoint &p )
 	++index;
     if ( !insertAnchor )
 	index = 0;
-    AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( tr( "Add Widget '%1' to Toolbar '%2'" ).
+    AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n( "Add Widget '%1' to Toolbar '%2'" ).
 								    arg( w->name() ).arg( caption() ),
 								    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
