@@ -33,12 +33,11 @@
 #include "project.h"
 
 #include <kiconloader.h>
+#include <klineedit.h>
 #include "kdevdesigner_part.h"
-#include <kdebug.h>
 
 #include <qlistview.h>
 #include <qpushbutton.h>
-#include <qlineedit.h>
 #include <qcombobox.h>
 #include <qstrlist.h>
 #include <qmessagebox.h>
@@ -128,19 +127,6 @@ EditFunctions::EditFunctions( QWidget *parent, FormWindow *fw, bool justSlots )
 			  SLOT( setText( const QString & ) ) );
     }
     delete l;
-
-	functionSpecifier->insertItem( "non virtual" );
-	functionSpecifier->insertItem( "virtual" );
-	functionSpecifier->insertItem( "pure virtual" );
-	functionSpecifier->insertItem( "static" );
-	
-	functionAccess->insertItem( "public" );
-	functionAccess->insertItem( "protected" );
-	functionAccess->insertItem( "private" );
-	
-	functionType->insertItem( "slot" );
-	functionType->insertItem( "function" );
-
 }
 
 void EditFunctions::okClicked()
