@@ -67,6 +67,11 @@ CCConfigWidget::CCConfigWidget( CppSupportPart* part, QWidget* parent, const cha
 	connect( m_pPart->codeRepository(), SIGNAL( catalogUnregistered( Catalog* ) ),
 	         this, SLOT( catalogUnregistered( Catalog* ) ) );
 
+	connect( m_qtDir, SIGNAL(urlSelected(const QString &)), 
+		 this, SLOT(isValidQtDir(const QString &)));
+	connect( m_qtDir, SIGNAL(textChanged(const QString &)), 
+		 this, SLOT(isValidQtDir(const QString &)));
+
 	initGeneralTab( );
 	initQtTab();
 	initCodeCompletionTab( );
@@ -129,17 +134,33 @@ void CCConfigWidget::initCodeCompletionTab( )
 	checkAutomaticCodeCompletion->setChecked( c->automaticCodeCompletion() );
 	checkAutomaticArgumentsHint->setChecked( c->automaticArgumentsHint() );
 
-	m_includeGlobalFunctions->setChecked( c->includeGlobalFunctions() );
-	m_includeTypes->setChecked( c->includeTypes() );
-	m_includeEnums->setChecked( c->includeEnums() );
-	m_includeTypedefs->setChecked( c->includeTypedefs() );
+	checkCompleteArgumentType->setChecked( c->processFunctionArguments() );
+	checkCompleteReturnType->setChecked( c->processPrimaryTypes() );
+	checkShowOnlyAccessible->setChecked( c->showOnlyAccessibleItems() );
+
+	editNamespaceAlias->setText( c->namespaceAliases() );
+	checkBox18->setChecked( c->showEvaluationContextMenu() );
+	checkShowTypeEvaluationInStatusBar->setChecked( c->statusBarTypeEvaluation() );
+	checkShowCommentInArgumentHint->setChecked( c->showCommentWithArgumentHint() );
+	
+	switch( c->completionBoxItemOrder() ) {
+	case CppCodeCompletionConfig::ByAccessLevel:
+		radioGroupByAccess->setChecked( true );
+		break;
+	case CppCodeCompletionConfig::ByClass:
+		radioGroupByClass->setChecked( true );
+		break;
+	case CppCodeCompletionConfig::ByAlphabet:
+		radioGroupByAlphabet->setChecked( true );
+		break;
+	}
 
 	QValueList<Catalog*> catalogs = m_pPart->codeRepository() ->registeredCatalogs();
 	for ( QValueList<Catalog*>::Iterator it = catalogs.begin(); it != catalogs.end(); ++it )
 	{
 		Catalog* c = *it;
 		QFileInfo dbInfo( c->dbName() );
-		QCheckListItem* item = new QCheckListItem( advancedOptions, dbInfo.baseName(), QCheckListItem::CheckBox );
+		QCheckListItem* item = new QCheckListItem( advancedOptions, KURL::decode_string( dbInfo.baseName() ), QCheckListItem::CheckBox );
 		item->setOn( c->enabled() );
 
 		m_catalogs[ item ] = c;
@@ -156,10 +177,23 @@ void CCConfigWidget::saveCodeCompletionTab( )
 	c->setAutomaticCodeCompletion( checkAutomaticCodeCompletion->isChecked() );
 	c->setAutomaticArgumentsHint( checkAutomaticArgumentsHint->isChecked() );
 
-	c->setIncludeGlobalFunctions( m_includeGlobalFunctions->isChecked() );
-	c->setIncludeTypes( m_includeTypes->isChecked() );
-	c->setIncludeEnums( m_includeEnums->isChecked() );
-	c->setIncludeTypedefs( m_includeTypedefs->isChecked() );
+	c->setProcessFunctionArguments( checkCompleteArgumentType->isChecked() );
+	c->setProcessPrimaryTypes( checkCompleteReturnType->isChecked() );
+	c->setShowOnlyAccessibleItems( checkShowOnlyAccessible->isChecked() );
+	
+	c->setNamespaceAliases( editNamespaceAlias->text() );
+	c->setShowEvaluationContextMenu( checkBox18->isChecked() );
+	c->setStatusBarTypeEvaluation( checkShowTypeEvaluationInStatusBar->isChecked() );
+	c->setShowCommentWithArgumentHint( checkShowCommentInArgumentHint->isChecked() );
+
+	if( radioGroupByAccess->isChecked() )
+		c->setCompletionBoxItemOrder( CppCodeCompletionConfig::ByAccessLevel );
+
+	if( radioGroupByClass->isChecked() )
+		c->setCompletionBoxItemOrder( CppCodeCompletionConfig::ByClass );
+
+	if( radioGroupByAlphabet->isChecked() )
+		c->setCompletionBoxItemOrder( CppCodeCompletionConfig::ByAlphabet );
 
 	for ( QMap<QCheckListItem*, Catalog*>::Iterator it = m_catalogs.begin(); it != m_catalogs.end(); ++it )
 	{
@@ -185,7 +219,7 @@ void CCConfigWidget::slotRemovePCS()
 	QString question = i18n( "Are you sure you want to remove the \"%1\" database?" ).arg( db );
 
 	KStandardDirs *dirs = m_pPart->instance() ->dirs();
-	QString dbName = dirs->saveLocation( "data", "kdevcppsupport/pcs" ) + db + ".db";
+	QString dbName = dirs->saveLocation( "data", "kdevcppsupport/pcs" ) + KURL::encode_string_no_slash( db ) + ".db";
 	
 #if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
 
@@ -204,7 +238,7 @@ void CCConfigWidget::slotRemovePCS()
 void CCConfigWidget::catalogRegistered( Catalog * c )
 {
 	QFileInfo dbInfo( c->dbName() );
-	QCheckListItem* item = new QCheckListItem( advancedOptions, dbInfo.baseName(), QCheckListItem::CheckBox );
+	QCheckListItem* item = new QCheckListItem( advancedOptions, KURL::decode_string( dbInfo.baseName() ), QCheckListItem::CheckBox );
 	item->setOn( c->enabled() );
 
 	m_catalogs[ item ] = c;
@@ -355,16 +389,44 @@ void CCConfigWidget::saveSplitTab( )
 
 void CCConfigWidget::initQtTab()
 {
+	m_qtDir->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);
+	
 	QtBuildConfig* c = m_pPart->qtBuildConfig();
 
 	m_qtUsed->setChecked( c->isUsed() );
 	if( c->version() == 4 )
 	{
-		m_qtVersion4->setChecked( true );
+		m_versionQt4->setChecked( true );
+		m_kdevembedded->setEnabled( false );
+		m_kdevexternal->setEnabled( false );
+		m_qtStyleVersion4->setEnabled( true );
 	}
 	else
 	{
-		m_qtVersion3->setChecked( true );
+		m_versionQt3->setChecked( true );
+		m_kdevembedded->setEnabled( true );
+		m_kdevexternal->setEnabled( true );
+		m_qtStyleVersion4->setEnabled( false );
+	}
+	if( c->includeStyle() == 4 )
+	{
+		m_qtStyleVersion4->setChecked( true );
+	}else
+	{
+		m_qtStyleVersion3->setChecked( true );
+	}
+	m_qtDir->setURL( c->root() );
+	isValidQtDir(m_qtDir->url());
+	if ( c->designerIntegration() == "EmbeddedKDevDesigner" )
+	{
+		m_kdevembedded->setChecked( true );
+	}
+	else if ( c->designerIntegration() == "ExternalKDevDesigner" )
+	{
+		m_kdevexternal->setChecked( true );
+	}else
+	{
+		m_qtdesigner->setChecked( true );
 	}
 }
 
@@ -373,7 +435,7 @@ void CCConfigWidget::saveQtTab()
 	QtBuildConfig* c = m_pPart->qtBuildConfig();
 	
 	c->setUsed( m_qtUsed->isChecked() );
-	if( m_qtVersion4->isChecked() )
+	if( m_versionQt4->isChecked() )
 	{
 		c->setVersion( 4 );
 	}
@@ -381,10 +443,57 @@ void CCConfigWidget::saveQtTab()
 	{
 		c->setVersion( 3 );
 	}
-	
+	if( m_qtStyleVersion4->isChecked() )
+	{
+		c->setIncludeStyle( 4 );
+	}else
+	{
+		c->setIncludeStyle( 4 );
+	}
+	c->setRoot( m_qtDir->url() );
+	if( m_kdevembedded->isChecked() )
+	{
+		c->setDesignerIntegration( "EmbeddedKDevDesigner" );
+	}
+	else if ( m_kdevexternal->isChecked() )
+	{
+		c->setDesignerIntegration( "ExternalKDevDesigner" );
+	}else
+	{
+		c->setDesignerIntegration( "ExternalDesigner" );
+	}
 	c->store();
 }
 
+void CCConfigWidget::isValidQtDir( const QString &dir )
+{
+	if ( !QFile::exists( dir + "/include/qt.h" ) && !QFile::exists( dir + "/include/Qt/qglobal.h" ) )
+	{
+		m_qtDir->lineEdit()->setPaletteForegroundColor(QColor("#ff0000"));
+	}else
+	{
+		m_qtDir->lineEdit()->unsetPalette();
+	}
+}
+
+void CCConfigWidget::toggleQtVersion( bool )
+{
+  if ( m_versionQt3->isChecked() )
+  {
+    m_qtStyleVersion4->setEnabled( false );
+    m_qtStyleVersion3->setChecked( true );
+    m_kdevembedded->setEnabled( true );
+    m_kdevexternal->setEnabled( true );
+  }
+  if ( m_versionQt4->isChecked() )
+  {
+    m_qtStyleVersion4->setEnabled( true );
+    m_qtdesigner->setChecked( true );
+    m_kdevembedded->setEnabled( false );
+    m_kdevexternal->setEnabled( false );
+  }
+}
+
 #include "ccconfigwidget.moc"
 
 //kate: indent-mode csands; tab-width 4; space-indent off;
