@@ -1,10 +1,13 @@
-
-#include "cppsupport_utils.h"
-#include <codemodel.h>
 #include <qdir.h>
 
+#include <kapplication.h>
+#include <kconfig.h>
 #include <kdebug.h>
 
+#include <codemodel.h>
+
+#include "cppsupport_utils.h"
+
 static void typeNameList( QStringList& path, QStringList & lst, const CodeModel * model );
 static void typeNameList( QStringList& path, QStringList & lst, NamespaceDom ns );
 static void typeNameList( QStringList & path, QStringList & lst, ClassDom klass );
@@ -115,4 +118,22 @@ static void typedefMap( QMap<QString, QString> & map, ClassDom klass )
 		typedefMap( map, *it );
 }
 
+QString formattedOpeningParenthesis(bool suppressSpace)
+{
+	KConfig * config = kapp->config();
+	config->setGroup("AStyle");
+	bool use_spaces = config->readBoolEntry("PadParentheses", false);
+	if (not use_spaces or suppressSpace) return "(";
+	return "( ";
+}
+
+QString formattedClosingParenthesis(bool suppressSpace)
+{
+	KConfig * config = kapp->config();
+	config->setGroup("AStyle");
+	bool use_spaces = config->readBoolEntry("PadParentheses", false);
+	if (not use_spaces or suppressSpace) return ")";
+	return " )";
+}
+
 //kate: indent-mode csands; tab-width 4; space-indent off;
