@@ -39,6 +39,7 @@
 #include "kdevsourceformatter.h"
 #include "kdevcreatefile.h" 
 #include "qtbuildconfig.h"
+#include <kpopupmenu.h>
 // wizards
 #include "cppnewclassdlg.h"
 #include "subclassingdlg.h"
@@ -102,8 +103,9 @@
 ///Currently activating this leads to mysterious crashes, but on long-term it's better
 const bool alwaysParseInBackground = false;
 
-enum { KDEV_DB_VERSION = 11 };
-enum { KDEV_PCS_VERSION = 9 };
+
+enum { KDEV_DB_VERSION = 12 };
+enum { KDEV_PCS_VERSION = 10 };
 
 QStringList CppSupportPart::m_sourceMimeTypes = QStringList() << "text/x-csrc" << "text/x-c++src";
 QStringList CppSupportPart::m_headerMimeTypes = QStringList() << "text/x-chdr" << "text/x-c++hdr";
@@ -237,6 +239,14 @@ CppSupportPart::CppSupportPart( QObject *parent, const char *name, const QString
 	action->setWhatsThis( i18n( "<b>Make member</b><p>Creates a class member function in implementation file "
 	                            "based on the member declaration at the current line." ) );
 	action->plug( new QWidget() );
+
+	action = new KAction( i18n( "Navigation Menu" ), 0, CTRL + ALT + Key_Space,
+	                      this, SLOT( slotNavigate() ),
+	                      actionCollection(), "edit_navigate" );
+	action->setToolTip( i18n( "Show the navigation-menu" ) );
+	action->setWhatsThis( i18n( "<b>Navigate</b><p>Shows a navigation-menu based on the type-evaluation of the item under the cursor." ) );
+	action->plug( new QWidget() );
+	
 	
 	action = new KAction( i18n( "New Class..." ), "classnew", 0,
 	                      this, SLOT( slotNewClass() ),
@@ -530,6 +540,23 @@ QString CppSupportPart::findHeader( const QStringList &list, const QString &head
 }
 
 
+void CppSupportPart::slotNavigate() {
+	if( codeCompletion() && m_activeView && m_activeViewCursor ) {
+		unsigned int curLine = 0, curCol = 0;
+		m_activeViewCursor->cursorPositionReal( &curLine, &curCol );
+
+		if( m_navigationMenu ) delete (KPopupMenu*)m_navigationMenu;
+		
+		m_navigationMenu = new KPopupMenu( m_activeView );
+		
+		codeCompletion()->contextEvaluationMenus( m_navigationMenu, 0, curLine, curCol );
+
+		m_navigationMenu->move( m_activeView->mapToGlobal( m_activeViewCursor->cursorCoordinates() ) );
+		m_navigationMenu->show();
+	}
+}
+
+
 void CppSupportPart::contextMenu( QPopupMenu *popup, const Context *context )
 {
 	m_activeClass = 0;
@@ -1994,7 +2021,6 @@ FileDom CppSupportPart::fileByName( const QString& name) {
 
 
 int CppSupportPart::parseFilesAndDependencies( QStringList files, bool background ) {
-
 	QMap<QString, int> fileGroups;
 	int nextGroup = 0;
 
@@ -2201,20 +2227,20 @@ void CppSupportPart::emitFileParsed( QStringList l )
 
 bool CppSupportPart::isHeader( const QString& fileName ) const
 {
-	KMimeType::Ptr ptr = KMimeType::findByPath( fileName );
+	/*KMimeType::Ptr ptr = KMimeType::findByPath( fileName );
 	if ( ptr && m_headerMimeTypes.contains( ptr->name() ) )
-		return true;
+		return true;*/
 	
-	return m_headerExtensions.contains( QFileInfo( fileName ).extension() );
+	return ( m_headerExtensions.findIndex( QFileInfo( fileName ).extension() ) != -1 );
 }
 
 bool CppSupportPart::isSource( const QString& fileName ) const
 {
-	KMimeType::Ptr ptr = KMimeType::findByPath( fileName );
+	/*KMimeType::Ptr ptr = KMimeType::findByPath( fileName );
 	if ( ptr && m_sourceMimeTypes.contains( ptr->name() ) )
-		return true;
+		return true;*/
 	
-	return m_sourceExtensions.contains( QFileInfo( fileName ).extension() );
+	return ( m_sourceExtensions.findIndex( QFileInfo( fileName ).extension() ) != -1 );
 }
 
 void CppSupportPart::gotoDeclarationLine( int line )
