@@ -32,6 +32,7 @@
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kstringhandler.h>
+#include <klineedit.h>
 
 #include <qprogressbar.h>
 #include <qheader.h>
@@ -39,7 +40,6 @@
 #include <qprocess.h>
 #include <qregexp.h>
 #include <qlayout.h>
-#include <qlineedit.h>
 #include <qtimer.h>
 #include <qpushbutton.h>
 
@@ -327,7 +327,7 @@ void CreatePCSDialog::slotSelected( const QString & )
 
 		KStandardDirs *dirs = m_part->instance() ->dirs();
 
-		QString dbName = dirs->saveLocation( "data", "kdevcppsupport/pcs" ) + filename_edit->text() + ".db";
+		QString dbName = dirs->saveLocation( "data", "kdevcppsupport/pcs" ) + KURL::encode_string_no_slash(filename_edit->text()) + ".db";
 		kdDebug( 9007 ) << "================================> dbName = " << dbName << endl;
 
 		m_part->removeCatalog( dbName );
