@@ -2,6 +2,9 @@
 *   Copyright (C) 2003 by Roberto Raggi                                   *
 *   roberto@kdevelop.org                                                  *
 *                                                                         *
+*   Copyright (C) 2006 by Jens Dagerbo                                    *
+*   jens.dagerbo@swipnet.se                                               *
+*                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
@@ -9,25 +12,21 @@
 *                                                                         *
 ***************************************************************************/
 
-#include "settingsdialog.h"
 #include <klistbox.h>
 #include <kcombobox.h>
+#include <kurlrequester.h>
+#include <kdebug.h>
+#include <klineedit.h>
+#include <kmessagebox.h>
+#include <klocale.h>
+
 #include <qfile.h>
 #include <qdir.h>
 #include <qregexp.h>
 #include <cstdlib>
 
-#if QT_VERSION < 0x030100 
-/* original source from qt-3.2.1/src/widgets/qlistbox.cpp
-QListBoxItem* QListBox::selectedItem() const
-{
-    if ( d->selectionMode != Single )
-	return 0;
-    if ( isSelected( currentItem() ) )
-	return  d->current;
-    return 0;
-}
-*/
+#include "settingsdialog.h"
+
 QListBoxItem* QListBox_selectedItem( QListBox* cpQListBox )
 {
 	if ( cpQListBox->selectionMode() != QListBox::Single )
@@ -36,17 +35,17 @@ QListBoxItem* QListBox_selectedItem( QListBox* cpQListBox )
 		return cpQListBox->item( cpQListBox->currentItem() );
 	return 0;
 }
-#endif
 
 SettingsDialog::SettingsDialog( QWidget* parent, const char* name, WFlags fl )
 		: SettingsDialogBase( parent, name, fl )
 {
 	QStringList qtdirs;
-	qtdirs.push_back( ::getenv( "QTDIR" ) );
-	qtdirs.push_back( "/usr/lib/qt3" );
-	qtdirs.push_back( "/usr/lib/qt" );
-	qtdirs.push_back( "/usr/share/qt3" );
-
+	qtdirs.push_back( ::getenv( "QTDIR" ) + QString("/include") );
+	qtdirs.push_back( "/usr/lib/qt3/include" );
+	qtdirs.push_back( "/usr/lib/qt/include" );
+	qtdirs.push_back( "/usr/share/qt3/include" );
+	qtdirs.push_back( "/usr/qt/3/include" );	// gentoo style
+	
 	for ( QStringList::Iterator it = qtdirs.begin(); it != qtdirs.end(); ++it )
 	{
 		QString qtdir = *it;
@@ -54,27 +53,24 @@ SettingsDialog::SettingsDialog( QWidget* parent, const char* name, WFlags fl )
 			if ( !qtListBox->findItem( qtdir, ExactMatch ) )
 				qtListBox->insertItem( qtdir );
 	}
+	
+	qtUrl->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+	
+	connect( addUrlButton, SIGNAL(clicked()), this, SLOT(addUrlButton_clicked()) );
 }
 
 SettingsDialog::~SettingsDialog()
 {}
 
-/*$SPECIALIZATION$*/
-void SettingsDialog::slotSelectionChanged( QListBoxItem* // item
-                                         )
+void SettingsDialog::slotSelectionChanged( QListBoxItem* )
 {
-#if QT_VERSION < 0x030100
-	if ( !QListBox_selectedItem( qtListBox ) )
-	{
-#else
 	if ( !qtListBox->selectedItem() )
 	{
-#endif
 		emit enabled( false );
 		return ;
 	}
 
-	QDir dir( qtDir() + "/include" );
+	QDir dir( qtDir() );
 	QStringList qconfigFileList = dir.entryList( "qconfig-*.h" );
 	qtConfiguration->clear();
 	QRegExp rx( "qconfig-(\\w+)\\.h" );
@@ -89,7 +85,7 @@ void SettingsDialog::slotSelectionChanged( QListBoxItem* // item
 
 bool SettingsDialog::isValidQtDir( const QString & path ) const
 {
-	return QFile::exists( path + "/include/qt.h" );
+	return QFile::exists( path + "/qt.h" );
 }
 
 QString SettingsDialog::qtDir( ) const
@@ -102,5 +98,26 @@ QString SettingsDialog::configuration( ) const
 	return qtConfiguration->currentText();
 }
 
+void SettingsDialog::addUrlButton_clicked( )
+{
+	kdDebug(9000) << k_funcinfo << endl;
+	
+	if ( isValidQtDir( qtUrl->url() ) )
+	{
+		qtListBox->insertItem( qtUrl->url() );
+		if ( QListBoxItem * item = qtListBox->findItem( qtUrl->url(), ExactMatch ) )
+		{
+			qtListBox->setSelected( item, true );
+		}
+		qtUrl->lineEdit()->clear();
+	}
+	else
+	{
+		KMessageBox::error( this, i18n("This doesn't appear to be a valid Qt3 include directory.\nPlease select a different directory."), i18n("Invalid Directory") );
+	}
+	
+}
+
 #include "settingsdialog.moc" 
 //kate: indent-mode csands; tab-width 4; space-indent off;
+
