@@ -20,6 +20,7 @@
 #define PROBLEMSREPORTER_H
 
 #include <klistview.h>
+#include <klineedit.h>
 #include <qguardedptr.h>
 #include <qdatetime.h>
 
@@ -28,7 +29,6 @@ class QTimer;
 class QTabBar;
 class QWidgetStack;
 class QGridLayout;
-class QLineEdit;
 class KDialogBase;
 class Problem;
 class KURL;
@@ -91,7 +91,7 @@ private:
 	KListView* m_warningList;
 	KListView* m_todoList;
 	KListView* m_filteredList;
-	QLineEdit* m_filterEdit;
+	KLineEdit* m_filterEdit;
 
 	CppSupportPart* m_cppSupport;
 	QGuardedPtr<KTextEditor::Document> m_document;
