@@ -23,6 +23,7 @@
 #include "completiondebug.h"
 #include "typedesc.h"
 #include "declarationinfo.h"
+#include <qpair.h>
 
 #include "cpp_tags.h"
 #include "codemodel.h"
@@ -189,14 +190,16 @@ void setGlobalNamespace( TypePointer globalNamespace );
 
 
 class SimpleTypeImpl : public KShared {
-  enum ResolutionFlags {
+	/*enum ResolutionFlags {
     NoFlag = 0,
     HadTypedef = 1,
     HadTemplate = 2,
     HadAlias = 3
-  };
+  };*/
 
 public:
+  typedef KSharedPtr<SimpleTypeImpl> TypePointer;
+	
   SimpleTypeImpl( const QStringList& scope ) :  m_resolutionCount(0), m_resolutionFlags(NoFlag), m_scope(scope) {
     checkTemplateParams();
     reg();
@@ -211,14 +214,6 @@ public:
     reg();
   };
   
-  typedef KSharedPtr<SimpleTypeImpl> TypePointer;
-  void tracePrepend( const TypeDesc& t ) {
-    m_trace.push_front( t );
-  }
-  
-  QValueList<TypeDesc> trace() {
-    return m_trace;
-  }
   
   class TemplateParamInfo {
   public:
@@ -323,7 +318,6 @@ public:
 private:
   int m_resolutionCount;
   ResolutionFlags m_resolutionFlags;
-  QValueList<TypeDesc> m_trace; ///pointer to the previous type in the trace-chain
 	
   SimpleTypeImpl( const SimpleTypeImpl& /*rhs*/ ) : KShared() {
   }
@@ -483,7 +477,7 @@ public:
   class MemberInfo {
     KSharedPtr<TypeBuildInfo> m_build;
   public:
-    
+
     enum MemberType {
       NotFound = 0,
         Function = 1,
@@ -494,11 +488,11 @@ public:
         Namespace = 32,
         AllTypes = 0xffffffff
     } memberType;
-    
+
     MemberInfo() {
       memberType = NotFound;
     }
-    
+
     QString memberTypeToString() {
       switch( memberType ) {
       case Namespace:
@@ -519,11 +513,13 @@ public:
         return "unknown";
       };
     }
-    
+
+    typedef KSharedPtr<SimpleTypeImpl> TypePointer;
+
     void setBuildInfo( KSharedPtr<TypeBuildInfo> build ) {
       m_build = build;
     }
-    
+
     TypePointer build() {
       if( !m_build)
         return TypePointer();
@@ -533,18 +529,19 @@ public:
         return r;
       }
     }
-    
+
     operator bool() const {
       return memberType != NotFound;
     }
-    
+
     QString name;
     TypeDesc type;
-    
-        ///This member is only filles for variables!
+
+        ///This member is only filles for variables, typedefs and template-params!
     DeclarationInfo decl;
   };
-  
+
+
   enum LocateMode {
     Normal = 1,
       ExcludeTemplates = 2,
@@ -565,69 +562,9 @@ public:
   TypeDesc replaceTemplateParams( TypeDesc desc, TemplateParamInfo& paramInfo );
   TypeDesc resolveTemplateParams( TypeDesc desc, LocateMode mode = Normal );
 
-	class LocateResult {
-		TypeDesc m_desc;
-		int m_resolutionCount;
-		ResolutionFlags m_flags;
-	
-	public:
-		/*enum ResolutionFlags {
-			NoFlag = 0,
-			HadTypedef = 1,
-			HadTemplate = 2,
-			HadAlias = 3
-		};*/
-	public:
+	typedef ::LocateResult LocateResult;
 
-		LocateResult( const TypeDesc& desc = TypeDesc() ) : m_desc( desc ), m_resolutionCount(0), m_flags( NoFlag) {
-		}
 
-		LocateResult& operator = ( const TypeDesc& rhs ) {
-			m_desc = rhs;
-			return *this;
-		}
-		
-		operator TypeDesc() const {
-			return m_desc;
-		}
-
-		TypeDesc& desc() {
-			return m_desc;
-		}
-
-		operator bool() const {
-			return (bool)m_desc;
-		}
-
-		bool operator >( const LocateResult& rhs ) const {
-			return m_resolutionCount > rhs.m_resolutionCount;
-		}
-
-		const TypeDesc* operator ->() const {
-			return &m_desc;
-		}
-
-		TypeDesc* operator ->() {
-			return &m_desc;
-		}
-
-		int resolutionCount() const {
-			return m_resolutionCount;
-		}
-
-		void increaseResolutionCount() {
-			m_resolutionCount++;
-		}
-
-		void addResolutionFlag( ResolutionFlags flag ) {
-			m_flags = addFlag(flag, m_flags);
-		}
-
-		bool hasResolutionFlag( ResolutionFlags flag ) const {
-			return (bool) ( m_flags & flag );
-		}
-	};
-	
     /**By default templates are included while the resolution, so when the type should be addressed from
     outside of the class, ExcludeTemplates should be set as LocateMode, since templates can not be directly accessed    from the outside.
     The resulting type's template-params may not be completely resolved, but can all be resolved locally by that type*/
@@ -733,13 +670,16 @@ public:
     
     ///this completely evaluates everything
   QString fullTypeResolvedWithScope( int depth = 0 );
+
+	
+  QString fullTypeUnresolvedWithScope();
   
 private:
   QStringList m_scope;
   TypePointer m_parent;
-  
+
 protected:
-  SimpleTypeImpl( SimpleTypeImpl* rhs ) : m_masterProxy( rhs->m_masterProxy ), m_resolutionCount( rhs->m_resolutionCount ), m_resolutionFlags( rhs->m_resolutionFlags ), m_trace( rhs->m_trace ), m_scope( rhs->m_scope ), m_parent( rhs->m_parent ), m_desc( rhs->m_desc )  {
+  SimpleTypeImpl( SimpleTypeImpl* rhs ) : m_masterProxy( rhs->m_masterProxy ), m_resolutionCount( rhs->m_resolutionCount ), m_resolutionFlags( rhs->m_resolutionFlags ), m_scope( rhs->m_scope ), m_parent( rhs->m_parent )/*, m_trace( rhs->m_trace )*/, m_desc( rhs->m_desc )  {
    reg();
   }
   
@@ -753,6 +693,21 @@ protected:
   TypeOfResult searchBases ( const TypeDesc& name );
 };
 
+
+class TypeTrace {
+	QValueList<QPair< SimpleTypeImpl::MemberInfo, TypeDesc> > m_trace;
+public:
+	
+	QValueList<QPair< SimpleTypeImpl::MemberInfo, TypeDesc> >& trace() {
+		return m_trace;
+	};
+	
+	void prepend( const SimpleTypeImpl::MemberInfo& t, const TypeDesc& tail = TypeDesc() ) {
+		m_trace.push_front( QPair< SimpleTypeImpl::MemberInfo, TypeDesc>( t, tail ) );
+	}
+};
+
+
 #endif
 // kate: indent-mode csands; tab-width 4;
 
