@@ -124,6 +124,7 @@ void SimpleTypeFunctionInterface::resolveImplicitTypes( QValueList<TypeDesc>& ar
 
  void SimpleTypeFunctionInterface::appendNextFunction( SimpleType func ) {
    if( !func )return;
+   if( (SimpleTypeImpl*)func.get() == (SimpleTypeImpl*)this ) return;
    if( m_nextFunction && m_nextFunction->asFunction() ) {
      m_nextFunction->asFunction()->appendNextFunction( func );
    } else {
@@ -221,7 +222,7 @@ ClassDom SimpleTypeCodeModel::pickMostRelated( ClassList lst, QString fn ) {
 }
 
 
-SimpleTypeImpl::MemberInfo SimpleTypeCodeModel::findMember( TypeDesc name , SimpleTypeImpl::MemberInfo::MemberType type ) 
+SimpleTypeImpl::MemberInfo SimpleTypeCodeModel::findMember( TypeDesc name , MemberInfo::MemberType type )
 {
   MemberInfo ret;
   ret.name = name.name();
@@ -246,6 +247,38 @@ SimpleTypeImpl::MemberInfo SimpleTypeCodeModel::findMember( TypeDesc name , Simp
       d->getStartPosition( &ret.decl.startLine, &ret.decl.startCol );
       d->getEndPosition( &ret.decl.endLine, &ret.decl.endCol );
     }
+  } else if( klass->hasTypeAlias( name.name() ) && ( type & MemberInfo::Typedef ) ) {
+    ret.memberType = MemberInfo::Typedef;
+    TypeAliasList l = klass->typeAliasByName( name.name() );
+    if( !l.isEmpty() && l.front() ) {
+      ret.type = l.front()->type();
+	  ret.decl.name = l.front()->name();
+	  ret.decl.file = l.front()->fileName();
+	  ret.decl.comment = l.front()->comment();
+	  l.front()->getStartPosition( &ret.decl.startLine, &ret.decl.startCol );
+	  l.front()->getEndPosition( &ret.decl.endLine, &ret.decl.endCol );
+    }
+  } else if( klass->hasEnum( name.name() ) && ( type & MemberInfo::Typedef ) ) {
+    ret.memberType = MemberInfo::Typedef;
+    EnumDom e = klass->enumByName( name.name() );
+      ret.type = "int";
+	  ret.decl.name = e->name();
+	  ret.decl.file = e->fileName();
+	  ret.decl.comment = e->comment();
+	  e->getStartPosition( &ret.decl.startLine, &ret.decl.startCol );
+	  e->getEndPosition( &ret.decl.endLine, &ret.decl.endCol );
+  } else if ( klass->hasClass( name.name() ) && ( type & MemberInfo::NestedType ) ) {
+    ClassList l = klass->classByName( name.name() );
+    
+    if( !l.isEmpty() ) {
+      ClassDom i = pickMostRelated( l, globalCurrentFile );
+      if( i ) {
+        ret.setBuildInfo( new CodeModelBuildInfo( model_cast<ItemDom>( i ), name, TypePointer( this ) ) );
+        
+        ret.memberType = MemberInfo::NestedType;
+        ret.type = name;
+      }
+    }
   } else if( klass->hasFunction( name.name() )  && ( type & MemberInfo::Function ) ) {
     ret.memberType = MemberInfo::Function;
     FunctionList l = klass->functionByName( name.name() );
@@ -262,24 +295,6 @@ SimpleTypeImpl::MemberInfo SimpleTypeCodeModel::findMember( TypeDesc name , Simp
       ret.type = l.front()->resultType();
       ret.type.increaseFunctionDepth();
     }
-  } else if( klass->hasTypeAlias( name.name() ) && ( type & MemberInfo::Typedef ) ) {
-    ret.memberType = MemberInfo::Typedef;
-    TypeAliasList l = klass->typeAliasByName( name.name() );
-    if( !l.isEmpty() && l.front() ) {
-      ret.type = l.front()->type();
-    }
-  } else if ( klass->hasClass( name.name() ) && ( type & MemberInfo::NestedType ) ) {
-    ClassList l = klass->classByName( name.name() );
-    
-    if( !l.isEmpty() ) {
-      ClassDom i = pickMostRelated( l, globalCurrentFile );
-      if( i ) {
-        ret.setBuildInfo( new CodeModelBuildInfo( model_cast<ItemDom>( i ), name, TypePointer( this ) ) );
-        
-        ret.memberType = MemberInfo::NestedType;
-        ret.type = name;
-      }
-    }
   } else if ( ns && ns->hasNamespace( name.name() )  && ( type & MemberInfo::Namespace ) ) {
     ret.setBuildInfo( new CodeModelBuildInfo( model_cast<ItemDom>( ns->namespaceByName( name.name() )), name, TypePointer( this ) ) );
     ret.memberType = MemberInfo::Namespace;
@@ -290,6 +305,12 @@ SimpleTypeImpl::MemberInfo SimpleTypeCodeModel::findMember( TypeDesc name , Simp
       if( s ) {
         ret.memberType = MemberInfo::Template;
         ret.type = s;
+		ret.decl.name = name.name();
+	  if( m_item ) {
+		  ret.decl.file = m_item->fileName();
+		  m_item->getStartPosition( &ret.decl.startLine, &ret.decl.startCol );
+		  m_item->getEndPosition( &ret.decl.endLine, &ret.decl.endCol );
+	  }
       }
     }
   }
