@@ -1,5 +1,5 @@
 /*
- * Copyright (C) $YEAR$ $AUTHOR$ <$EMAIL$>
+ * Copyright (C) %{YEAR} %{AUTHOR} <%{EMAIL}>
  */
 
 #include <kapp.h>
@@ -9,7 +9,7 @@
 
 int main(int argc, char **argv)
 {
-    KApplication app(argc, argv, "$APPNAMELC$_client", false);
+    KApplication app(argc, argv, "%{APPNAMELC}_client", false);
 
     // get our DCOP client and attach so that we may use it
     DCOPClient *client = app.dcopClient();
@@ -22,7 +22,7 @@ int main(int argc, char **argv)
         ds << QString(argv[1]);
     else
         ds << QString("http://www.kde.org");
-    client->send("$APPNAMELC$", "$APPNAME$Iface", "openURL(QString)", data);
+    client->send("%{APPNAMELC}", "%{APPNAME}Iface", "openURL(QString)", data);
 
     return app.exec();
 }
