@@ -23,6 +23,7 @@
 #include "variablewidget.h"
 #include "jdbcommand.h"
 #include "stty.h"
+#include "settings.h"
 
 #include <kapplication.h>
 #include <kconfig.h>
@@ -41,7 +42,6 @@
 
 #include <iostream>
 #include <ctype.h>
-#include <stdlib.h>
 
 using namespace std;
 
@@ -431,13 +431,10 @@ char* JDBController::parseLine(char *buf)
 
 
                     emit showStepInSource(QString(classpath_ + "/" + mainclass_ + ".java").latin1(),
-                                          atoi(ex.cap(3).latin1()), "");
+                                          ex.cap(3).toInt(), "");
                     actOnProgramPause(QString("Reached Breakpoint in line ")+ex.cap(3));
 
-                    char *retStr;
-		    QString retQString =  QString( buf + ex.cap(ex.numCaptures()) );
-		    memcpy( retStr, retQString.latin1(), retQString.length() );
-                    return retStr;
+                    return  buf + ex.matchedLength();
                 }
 
             }
@@ -785,7 +782,7 @@ void JDBController::analyzeDump(QString data)
           item->value="null";
       }
       if (!localData[name]) {
-          kdDebug() << "inserting local var " << name << " at " << (int)item << endl;
+          kdDebug() << "inserting local var " << name << " at " << (long)item << endl;
           localData.insert(name, item);
       } else { /* The object is already being referred to as a property */ }
 
@@ -811,7 +808,7 @@ void JDBController::analyzeDump(QString data)
       if (!localData[name]) {
           /** oops, we should already have added that object @todo insert assertion */
           item = new JDBVarItem();
-          kdDebug() << "NAME: " << name << " - " << (int)item << endl;
+          kdDebug() << "NAME: " << name << " - " << (long)item << endl;
           item->name = name;
           localData.insert(name, item);
       } else {
@@ -886,7 +883,7 @@ void JDBController::analyzeDump(QString data)
                      localData.insert(fullName, subItem);
                  } else { /* Oops */ }  /// @todo insert assertion
 
-                 kdDebug() << "appending: " << fullName << " as " << (int)subItem << endl;
+                 kdDebug() << "appending: " << fullName << " as " << (long)subItem << endl;
 
                  // item.insertSibling(subItem);
                  item->siblings.append(subItem);
@@ -1086,7 +1083,8 @@ void JDBController::slotStart(const QString &/*application*/, const QString &arg
     // Remove .class suffix and leading path information from appname
     // (should not be there anyway)
 
-    tty_ = new STTY(config_dbgTerminal_, "konsole");
+//    tty_ = new STTY(config_dbgTerminal_, "konsole");
+    tty_ = new STTY(config_dbgTerminal_, Settings::terminalEmulatorName( *kapp->config() ));
     if (!config_dbgTerminal_) {
         connect( tty_, SIGNAL(OutOutput(const char*)), SIGNAL(ttyStdout(const char*)) );
         connect( tty_, SIGNAL(ErrOutput(const char*)), SIGNAL(ttyStderr(const char*)) );
