@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
 
@@ -641,9 +641,6 @@ void PHPSupportPart::customEvent( QCustomEvent* ev )
          if (LastClass != NULL) {
             LastClass->addFunction(nMethod);
          } else {
-            FunctionDom nMethodOld = ns->functionByName( event->name() )[0];
-            if ( nMethodOld != NULL)
-               ns->removeFunction( nMethodOld );
             ns->addFunction(nMethod);
          }
          LastMethod = nMethod;
