@@ -147,8 +147,7 @@ struct LexerData;
 
 class Token
 {
-public:
-    Token();
+    Token(const QString &);
     Token( int type, int position, int length, const QString& text );
     Token( const Token& source );
 
@@ -156,6 +155,7 @@ public:
     bool operator == ( const Token& token ) const;
     operator int () const;
 
+public:
     bool isNull() const;
 
     int type() const;
@@ -173,7 +173,7 @@ public:
     void setPosition( int position );
 
     QString text() const;
-    
+
 private:
     int m_type;
     int m_position;
@@ -182,7 +182,7 @@ private:
     int m_startColumn;
     int m_endLine;
     int m_endColumn;
-    QString m_text;
+    const QString & m_text;
 
     friend class Lexer;
     friend class Parser;
@@ -319,11 +319,11 @@ private:
 };
 
 
-inline Token::Token()
+inline Token::Token(const QString & text = "")
     : m_type( -1 ),
       m_position( 0 ),
       m_length( 0 ),
-      m_text( 0 )
+      m_text( text )
 {
 }
 
@@ -356,7 +356,7 @@ inline Token& Token::operator = ( const Token& source )
     m_startColumn = source.m_startColumn;
     m_endLine = source.m_endLine;
     m_endColumn = source.m_endColumn;
-    m_text = source.m_text;
+//    m_text = source.m_text;
     return( *this );
 }
 
@@ -406,7 +406,7 @@ inline void Token::setStartPosition( int line, int column )
 {
     m_startLine = line;
     m_startColumn = column;
-}
+} 
 
 inline void Token::setEndPosition( int line, int column )
 {
