@@ -19,21 +19,23 @@
 #ifndef KLISTVIEWACTION_H
 #define KLISTVIEWACTION_H
 
+#include <kxmlguiclient.h>
 #include <kdeversion.h>
-#if KDE_VERSION > 305
-# include <kaction.h>
-#else
-# include <kdevwidgetaction.h>
-#endif
+#include <kaction.h>
 
 class KComboView;
+ 
+/**
+@file klistviewaction.h
+Widget action with KComboView.
+*/
 
-class KListViewAction
-#if KDE_VERSION > 305
-: public KWidgetAction
-#else
-: public KDevCompat::KWidgetAction
-#endif
+
+/**
+Widget action with KComboView.
+Can be used on toolbars. It appears as @ref ResizableCombo.
+*/
+class KListViewAction: public KWidgetAction
 {
 public:
     KListViewAction(KComboView *view, const QString &text, const KShortcut &cut, const QObject *receiver, const char *slot, KActionCollection *parent, const char *name);
