@@ -26,10 +26,11 @@
 class QWidget;
 class QString;
 
+/**Namespace which contain property editing classes.*/
 namespace PropertyLib{
 
 /** @file property.h
-@short Contains @ref Property class and @ref PropertyType enum.
+@short Contains @ref PropertyLib::Property class and @ref PropertyLib::Property::PropertyType enum.
 */
 
 /**
@@ -39,7 +40,7 @@ It includes support for QStringList properties, an i18n'ed label and stores an o
 
 Contains name, type and value.
 
-Type can be one of predefined types (including standard @ref QVariant types) by @ref PropertyType 
+Type can be one of predefined types (including standard @ref QVariant types) by @ref PropertyLib::Property::PropertyType 
 enum or custom user type. User defined types should have values more than 3000.
 
 Value is a @ref QVariant.
@@ -108,6 +109,7 @@ public:
         FontName = 2002                    /**<font name, e.g. "times new roman"*/,
         FileURL = 2003                     /**<url of a file*/,
         DirectoryURL = 2004                /**<url of a directory*/,
+        LineStyle = 2005                   /**<line style*/,
 
         UserDefined = 3000                 /**<plugin defined properties should start here*/
     };
