@@ -66,6 +66,7 @@
 #include "kdevversioncontrol.h"
 #include "kdevmakefrontend.h"
 #include "kdevpartcontroller.h"
+#include "kdevplugincontroller.h"
 #include "kdevappfrontend.h"
 #include "kdevplugininfo.h"
 #include "kdevlicense.h"
@@ -76,6 +77,10 @@
 #include "misc.h"
 #include "profilesupport.h"
 #include "filetemplate.h"
+#include "settings.h"
+
+#include "profileengine.h"
+#include "profile.h"
 
 #include "propeditor/property.h"
 #include "propeditor/multiproperty.h"
@@ -83,7 +88,7 @@
 #include "propeditor/propertyeditor.h"
 
 AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const char *name)
-    : AppWizardDialogBase(parent, name,true), m_pCurrentAppInfo(0), 
+    : AppWizardDialogBase(parent, name,true), m_pCurrentAppInfo(0),
 	m_profileSupport(new ProfileSupport(part))
 {
 	kdDebug( 9000 ) << "  ** AppWizardDialog::AppWizardDialog()" << endl;
@@ -201,7 +206,7 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
 				value.cast( variantType );  // fix this in kdelibs...
 				if( !name.isEmpty() && !label.isEmpty() )
 					info->propValues->addProperty( new PropertyLib::Property( (int)variantType, name, label, value ) );
-				
+
 			}
 			else if( type == "install" ) // copy dir
 			{
@@ -312,10 +317,10 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
     }
 
 	connect( license_combo, SIGNAL(activated(int)), this, SLOT(licenseChanged()) );
-	
+
 	m_custom_options_layout = new QHBoxLayout( custom_options );
 	m_custom_options_layout->setAutoAdd(true);
-	
+
 	showTemplates(false);
 }
 
@@ -342,10 +347,9 @@ void AppWizardDialog::loadVcs()
 		KLibFactory *factory = KLibLoader::self()->factory(QFile::encodeName(service->library()));
 		if (!factory) {
 			QString errorMessage = KLibLoader::self()->lastErrorMessage();
-			// TODO messagebox?
-			kdWarning(9010) << "There was an error loading the module " << service->name() << endl <<
+			kdDebug(9010) << "There was an error loading the module " << service->name() << endl <<
 			"The diagnostics is:" << endl << errorMessage << endl;
-			continue;
+			exit(1);
 		}
 		QStringList args;
 		QObject *obj = factory->create(0, service->name().latin1(),
@@ -481,7 +485,7 @@ void AppWizardDialog::accept()
 	PropertyLib::PropertyList::Iterator idx = m_pCurrentAppInfo->propValues->begin();
 	for( ; idx != m_pCurrentAppInfo->propValues->end(); ++idx)
 		m_pCurrentAppInfo->subMap.insert( idx.data()->name(), idx.data()->value().toString() );
-	
+
 	m_pCurrentAppInfo->subMap.insert("src", archDir.name() );
 	m_pCurrentAppInfo->subMap.insert("dest", finalLoc_label->text() );
 	m_pCurrentAppInfo->subMap.insert("APPNAME", appname_edit->text() );
@@ -493,7 +497,7 @@ void AppWizardDialog::accept()
 	m_pCurrentAppInfo->subMap.insert("VERSION", version_edit->text());
 	m_pCurrentAppInfo->subMap.insert( "I18N", "i18n" );
 	m_pCurrentAppInfo->subMap.insert("YEAR", QString::number( QDate::currentDate().year() ) );
-	
+
 	// This isn't too pretty, but we have several templates that use KAboutData::License_${LICENSE}
 	// and unsurprisingly, KAboutData doesn't cover every imaginable case.
 	// These are the licenses known to KDE-3.2 KAboutData, KDevelop doesn't have all of these as prepared options today
@@ -525,8 +529,8 @@ void AppWizardDialog::accept()
 	QString tempProjectDomSource = "<!DOCTYPE kdevelop><kdevelop><general><author>%1</author><email>%2</email><version>%3</version></general></kdevelop>";
 	tempProjectDomSource = tempProjectDomSource.arg( author_edit->text() ).arg( email_edit->text() ).arg( version_edit->text() );
 	QDomDocument tempProjectDom;
-	tempProjectDom.setContent( tempProjectDomSource ); 
-	
+	tempProjectDom.setContent( tempProjectDomSource );
+
     QValueList<AppWizardFileTemplate>::Iterator it;
     for (it = m_fileTemplates.begin(); it != m_fileTemplates.end(); ++it) {
         KTempFile *tempFile = new KTempFile();
@@ -705,9 +709,9 @@ bool AppWizardDialog::copyFile( const installFile& file )
 		copyFile( file.source, file.dest, file.isXML, file.process );
 }
 
-#include <sys/types.h> 
-#include <sys/stat.h> 
-#include <unistd.h> 
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 bool AppWizardDialog::copyFile( const QString &source, const QString &dest, bool isXML, bool process )
 {
@@ -827,7 +831,7 @@ void AppWizardDialog::templatesTreeViewClicked(QListViewItem *item)
 		// Populate new custom options form
 		m_customOptions = new PropertyLib::PropertyEditor( custom_options );
 		m_customOptions->populateProperties(info->propValues);
-		
+
 
         // Create new file template pages
         QStringList l = QStringList::split(",", info->fileTemplates);
@@ -964,7 +968,7 @@ void AppWizardDialog::openAfterGeneration()
 	if( !file.open( IO_ReadOnly ) )
 		return;
 	QDomDocument projectDOM;
-	
+
 	int errorLine, errorCol;
 	QString errorMsg;
 	bool success = projectDOM.setContent( &file, &errorMsg, &errorLine, &errorCol);
@@ -988,41 +992,31 @@ void AppWizardDialog::openAfterGeneration()
 		DomUtil::writeEntry(projectDOM, "/general/versioncontrol", service->property("X-KDevelop-VCSPlugin").toString());
 	}
 
-	
-	KConfig * config = kapp->config();
-	config->setGroup("IgnorePerDefault");
-	QStringList ignoreparts = config->readListEntry( "KDevelop" );
-	DomUtil::writeListEntry( projectDOM, "/general/ignoreparts", "part", ignoreparts );
-	
-	
-//FIXME PROFILES!!!!!!!!
-//BEGIN Plugin Profile
-
-/*	QString category = m_pCurrentAppInfo->category;
-	if ( category.left( 1 ) == "/" )
+	// figure out what plugins we should disable by default
+	QString profileName = DomUtil::readEntry( projectDOM, "general/profile" );
+	if ( profileName.isEmpty() )
 	{
-		category = category.right( category.length() -1 );
+		QString language = DomUtil::readEntry( projectDOM, "general/primarylanguage" );
+		QStringList keywords = DomUtil::readListEntry( projectDOM, "general/keywords", "keyword" );
+
+		profileName = Settings::profileByAttributes( language, keywords );
 	}
 
-	QString profile = Profiles::getProfileForCategory( category );
-	QStringList loadList = Profiles::getPluginsForProfile( profile );
+	ProfileEngine & engine = m_part->pluginController()->engine();
+	Profile * profile = engine.findProfile( profileName );
 
-	QStringList ignoreList;
-
-	KTrader::OfferList offers = KTrader::self()->query("KDevelop/Plugin", "[X-KDevelop-Scope] == 'Project'");
-	KTrader::OfferList::ConstIterator itt = offers.begin();
-	while( itt != offers.end() )
+	QStringList disableList;
+	Profile::EntryList disableEntryList = profile->list( Profile::ExplicitDisable );
+	for ( Profile::EntryList::const_iterator it = disableEntryList.constBegin(); it != disableEntryList.constEnd(); ++it )
 	{
-		if ( !loadList.contains( (*itt)->name() ) )
-		{
-			ignoreList << (*itt)->name();
-		}
-		++itt;
+		disableList << (*it).name;
 	}
 
-	DomUtil::writeListEntry( projectDOM, "/general/ignoreparts", "part", ignoreList );*/
+	QStringList projectIgnoreparts = DomUtil::readListEntry( projectDOM, "/general/ignoreparts", "part" );
+	projectIgnoreparts += disableList;
+	DomUtil::writeListEntry( projectDOM, "/general/ignoreparts", "part", projectIgnoreparts );
 
-//END Plugin Profile
+	DomUtil::writeEntry( projectDOM, "/general/projectname", appname_edit->text() );
 
 	// write the dom back
 	if( !file.open( IO_WriteOnly ) )
@@ -1271,13 +1265,13 @@ void AppWizardDialog::showTemplates(bool all)
 	else
 	{
 		QPtrListIterator<ApplicationInfo> ait(m_appsInfo);
-		for (; ait.current(); ++ait) 
+		for (; ait.current(); ++ait)
 		{
 			ait.current()->item->setVisible(m_profileSupport->isInTemplateList(ait.current()->templateName));
 		}
-		
+
 		QDictIterator<QListViewItem> dit(m_categoryMap);
-		for (; dit.current(); ++dit) 
+		for (; dit.current(); ++dit)
 		{
 			//checking whether all children are not visible
 			kdDebug(9010) << "check: " << dit.current()->text(0) << endl;
