@@ -24,17 +24,25 @@ class KPopupMenu;
 class QHBoxLayout;
 class KArchiveDirectory;
 class KArchiveFile;
+class ProfileSupport;
 #include <qptrlist.h>
 #include <qdict.h>
-#include <qlineedit.h>
+#include <klineedit.h>
 #include <qlabel.h>
 #include <qstringlist.h>
 #include <klistview.h>
 #include <kiconview.h>
 #include "kdevversioncontrol.h"
+#include "kdevvcsintegrator.h"
 #include "appwizarddlgbase.h"
-//#include "vcs_form.h"
-#include "autoform.h"
+#include "vcs_form.h"
+//#include "autoform.h"
+#include "kdevlicense.h"
+
+namespace PropertyLib {
+	class PropertyList;
+	class PropertyEditor;
+}
 
 struct installFile
 {
@@ -75,12 +83,16 @@ struct ApplicationInfo
 	QMap<QString,QString> subMapXML;
     QStringList includes;
     
-    AutoPropertyMap subValues;
+	//QMap<autoKey,QVariant> subValues;
+	PropertyLib::PropertyList *propValues;
+	
     QValueList<installFile> fileList;
     QValueList<installArchive> archList;
     QValueList<installDir> dirList;
     QString customUI;
     QString message;
+    QString finishCmd;
+    QString finishCmdDir;
     QString sourceArchive;
 
     //! item pointer to the listview
@@ -113,12 +125,15 @@ class AppWizardDialog : public AppWizardDialogBase
 public:
     AppWizardDialog( AppWizardPart *part, QWidget *parent=0, const char *name=0 );
     ~AppWizardDialog();
-    QString getProjectName() { return appname_edit->text(); }
+    QString getProjectName() { return appname_edit->text().lower(); }
     QString getProjectLocation() { return finalLoc_label->text(); }
 
 protected:
     virtual void accept();
 
+	virtual QDict<KDevLicense> licenses();
+	void loadLicenses();
+
 protected slots:
     virtual void templatesTreeViewClicked(QListViewItem*);
     virtual void textChanged();
@@ -138,7 +153,7 @@ private: //methods
 
     ApplicationInfo *templateForItem(QListViewItem *item);
     void insertCategoryIntoTreeView(const QString &completeCategoryPath);
-//    void loadVcs();
+    void loadVcs();
 	void updateNextButtons();
 
 	void populateFavourites();
@@ -154,26 +169,39 @@ private: //methods
 	void setPermissions(const KArchiveFile *source, QString dest);
 	void setPermissions(const installFile &file);
 	
+	void checkAndHideItems(QListView *view);
+	bool checkAndHideItems(QListViewItem *item);
+	
 private: //data
 
     QPtrList<ApplicationInfo> m_appsInfo;
 	QValueList<AppWizardFileTemplate> m_fileTemplates;
     //! Store the category name and the pointer in the treeview
     QDict<QListViewItem> m_categoryMap;
+	QValueList<QListViewItem*> m_categoryItems;
     //! A list of currently available version control systems
 //    QDict<KDevVersionControl> m_availVcs;
 	
     QHBoxLayout *m_custom_options_layout;
-    AutoForm *m_customOptions;
+	PropertyLib::PropertyEditor *m_customOptions;
     AppWizardPart *m_part;
     QWidget *m_lastPage;
     QPtrList<KTempFile> m_tempFiles;
     ApplicationInfo* m_pCurrentAppInfo;
     bool m_projectLocationWasChanged;
-//    VcsForm *m_vcsForm;
+    VcsForm *m_vcsForm;
     bool m_pathIsValid;
 	KPopupMenu* m_favouritesMenu;
 	KPopupMenu* m_templatesMenu;
+	
+	QDict<KDevLicense> m_licenses;
+	QDict<KDevVCSIntegrator> m_integrators;
+	QMap<int, VCSDialog*> m_integratorDialogs;
+	
+	ProfileSupport *m_profileSupport;
+
+public slots:
+    virtual void showTemplates(bool all);
 };
 
 #endif
