@@ -21,7 +21,7 @@ class KURLRequester;
 class QGridLayout;
 class KComboBox;
 class QCheckBox;
-class QLineEdit;
+class KLineEdit;
 
 namespace FileCreate {
   class NewFileChooser : public KDialogBase {
@@ -36,16 +36,19 @@ namespace FileCreate {
     void setCurrent(const FileType *filetype);
     void setDirectory(const QString & url);
     void setName(const QString & name);
+    
+    void setInProjectMode(bool m);
   private slots:
       void slotFileNameChanged(const QString &);
   protected:
     void addType(const FileType * filetype);
+	void accept();
 
     QGridLayout *m_grid;
     KURLRequester *m_urlreq;
     KComboBox *m_filetypes;
     QCheckBox *m_addToProject;
-    QLineEdit *m_filename;
+    KLineEdit *m_filename;
 
     QMap<int,const FileType*> m_typeInCombo;
 
