@@ -70,6 +70,14 @@
 #include <kdebug.h>
 //END Includes
 
+#if defined(KDE_IS_VERSION)
+# if KDE_IS_VERSION(3,1,3)
+#  ifndef _KDE_3_1_3_
+#   define _KDE_3_1_3_
+#  endif
+# endif
+#endif
+
 // from kfiledialog.cpp - avoid qt warning in STDERR (~/.xsessionerrors)
 static void silenceQToolBar(QtMsgType, const char *)
 {}
@@ -141,7 +149,7 @@ KDevFileSelector::KDevFileSelector( FileSelectorPart *part, KDevMainWindow *main
     lo->addWidget(cmbPath);
     cmbPath->listBox()->installEventFilter( this );
 
-    dir = new KDevDirOperator(m_part, QString::null, this, "operator");
+    dir = new KDevDirOperator(m_part, KURL(), this, "operator");
     dir->setView(KFile::/*Simple*/Detail);
 
     KActionCollection *coll = dir->actionCollection();
@@ -244,7 +252,11 @@ void KDevFileSelector::readConfig(KConfig *config, const QString & name)
     setupToolbar( config );
 
     cmbPath->setMaxItems( config->readNumEntry( "pathcombo history len", 9 ) );
+#if defined(_KDE_3_1_3_)
+    cmbPath->setURLs( config->readPathListEntry("dir history") );
+#else
     cmbPath->setURLs( config->readListEntry("dir history") );
+#endif
     // if we restore history
     if ( config->readBoolEntry( "restore location", true ) || kapp->isRestored() )
     {
@@ -318,17 +330,11 @@ void KDevFileSelector::writeConfig(KConfig *config, const QString & name)
     {
         l.append( cmbPath->text( i ) );
     }
-    config->writeEntry("dir history", l );
-#if defined(KDE_IS_VERSION)
-# if KDE_IS_VERSION(3,1,3)
-#  ifndef _KDE_3_1_3_
-#   define _KDE_3_1_3_
-#  endif
-# endif
-#endif
 #if defined(_KDE_3_1_3_)
+    config->writePathEntry( "dir history", l );
     config->writePathEntry( "location", cmbPath->currentText() );
 #else
+    config->writeEntry( "dir history", l );
     config->writeEntry( "location", cmbPath->currentText() );
 #endif
 
@@ -350,8 +356,8 @@ void KDevFileSelector::setView(KFile::FileView view)
 
 void KDevFileSelector::slotFilterChange( const QString & nf )
 {
+    QToolTip::remove( btnFilter );
     QString f = nf.stripWhiteSpace();
-    QToolTip::remove(btnFilter);
     bool empty = f.isEmpty() || f == "*";
     if ( empty )
     {
@@ -451,7 +457,7 @@ void KDevFileSelector::autoSync( KParts::Part *part )
     KTextEditor::Document* doc = dynamic_cast<KTextEditor::Document*>( part );
     if( !doc )
 	return;
-    
+
     // as above, but using document url.
     kdDebug()<<"KDevFileSelector::autoSync( KTextEditor::Document )"<<endl;
     KURL u ( doc->url() );
@@ -564,10 +570,12 @@ private:
 
 KURL KDevFileSelector::activeDocumentUrl( )
 {
-    KTextEditor::Document* doc = dynamic_cast<KTextEditor::Document*>( partController->activePart() );
-    if( doc )
-	return doc->url();
-    
+	KParts::ReadOnlyPart * part = dynamic_cast<KParts::ReadOnlyPart*>( partController->activePart() );
+	if ( part )
+	{
+		return part->url();
+	}
+
     return KURL();
 }
 //END ActionLBItem
@@ -804,6 +812,9 @@ void KDevDirOperator::activatedMenu( const KFileItem *fi, const QPoint & pos )
         return;
     KPopupMenu *popup = am->popupMenu();
 
+    popup->insertSeparator();
+    m_part->newFileAction()->plug(popup);
+
     if (fi)
     {
         FileContext context( KURL::List(fi->url()));
