@@ -21,6 +21,7 @@
 #ifndef QUICKOPENDIALOG_H
 #define QUICKOPENDIALOG_H
 
+#include <codemodel.h>
 #include "quickopenbase.h"
 
 class QuickOpenPart;
@@ -36,6 +37,8 @@ public:
 
   virtual bool eventFilter(QObject *watched, QEvent *e);
   
+  void selectClassViewItem(ItemDom item); 
+  
 public slots:
   virtual void slotTextChanged(const QString&);
 
