@@ -8,33 +8,29 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+#include "replace_part.h"
 
 #include <qwhatsthis.h>
 
 #include <kaction.h>
 #include <kiconloader.h>
 #include <klocale.h>
-//#include <kgenericfactory.h>
 #include <kdevgenericfactory.h>
+#include <kdevplugininfo.h>
 #include <kdebug.h>
-#include <kiconloader.h>
 
 #include <kdevcore.h>
 #include <kdevmainwindow.h>
 
 #include "replace_widget.h"
-#include "replace_part.h"
 
-static const KAboutData data("kdevreplace", I18N_NOOP("Replace"), "1.0");
-
-//typedef KGenericFactory<ReplacePart> ReplaceFactory;
-//K_EXPORT_COMPONENT_FACTORY( libkdevreplace, ReplaceFactory( "kdevreplace" ) )
+static const KDevPluginInfo data("kdevreplace");
 
 typedef KDevGenericFactory<ReplacePart> ReplaceFactory;
-K_EXPORT_COMPONENT_FACTORY(libkdevreplace, ReplaceFactory(&data))
+K_EXPORT_COMPONENT_FACTORY(libkdevreplace, ReplaceFactory(data))
 
 ReplacePart::ReplacePart(QObject *parent, const char *name, const QStringList& )
-        : KDevPlugin( "Project Wide Replace", "", parent, name ? name : "ReplacePart" )
+        : KDevPlugin( &data, parent, name ? name : "ReplacePart" )
 {
     setInstance(ReplaceFactory::instance());
     setXMLFile("kdevpart_replace.rc");
@@ -55,7 +51,7 @@ ReplacePart::ReplacePart(QObject *parent, const char *name, const QStringList& )
 
     mainWindow()->embedOutputView( m_widget, i18n("Replace"), i18n("Project wide string replacement") );
 
-    KAction * action = new KAction(i18n("Find-Select-Replace..."), "replace project",
+    KAction * action = new KAction(i18n("Find-Select-Replace..."), 0,
                                    CTRL+SHIFT+Key_R, this, SLOT(slotReplace()), actionCollection(), "edit_replace_across");
     action->setToolTip( i18n("Project wide string replacement") );
     action->setWhatsThis( i18n("<b>Find-Select-Replace</b><p>"
@@ -64,8 +60,6 @@ ReplacePart::ReplacePart(QObject *parent, const char *name, const QStringList& )
                                "searched for within all files in the locations "
                                "you specify. Matches will be displayed in the <b>Replace</b> window, you "
                                "can replace them with the specified string, exclude them from replace operation or cancel the whole replace.") );
-
-    core()->insertNewAction( action );
 }
 
 
