@@ -18,12 +18,14 @@
 SnippetSettings::SnippetSettings(QWidget *parent, const char *name)
  : SnippetSettingsBase(parent, name)
 {
+  _widget = NULL;
 }
 
 SnippetSettings::SnippetSettings(SnippetWidget * w, QWidget *parent, const char *name)
  : SnippetSettingsBase(parent, name)
 {
   _cfg = w->getSnippetConfig();
+  _widget = w;
 }
 
 
@@ -40,6 +42,10 @@ void SnippetSettings::slotOKClicked()
     _cfg->setToolTips(cbToolTip->isChecked());
     _cfg->setDelimiter(leDelimiter->text());
     _cfg->setInputMethod(btnGroup->selectedId());
+    _cfg->setAutoOpenGroups(btnGroupAutoOpen->selectedId());
+
+    if (_widget)
+        _widget->languageChanged();
 }
 
 
