@@ -1,8 +1,8 @@
 #include "core.h"
 #include "codemodel.h"
 #include "partcontroller.h"
+#include "plugincontroller.h"
 #include "toplevel.h"
-#include "debugger.h"
 #include "api.h"
 
 
@@ -14,11 +14,6 @@ KDevMainWindow *API::mainWindow() const
   return TopLevel::getInstance();
 }
 
-bool API::mainWindowValid() const
-{
-  return TopLevel::mainWindowValid();
-}
-
 KDevPartController *API::partController() const
 {
   return PartController::getInstance();
@@ -37,12 +32,6 @@ CodeModel *API::codeModel() const
 }
 
 
-KDevDebugger *API::debugger() const
-{
-  return Debugger::getInstance();
-}
-
-
 API *API::getInstance()
 {
   if (!s_instance)
@@ -64,3 +53,8 @@ API::~API()
   m_classStore = 0;
 }
 
+KDevPluginController * API::pluginController() const
+{
+    return PluginController::getInstance();
+}
+
