@@ -33,7 +33,7 @@ int main(int argc, char *argv[])
   static const char description[] = I18N_NOOP("The KDevelop Integrated Development Environment");
   KAboutData aboutData("kdevelop", I18N_NOOP("KDevelop"),
                        VERSION, description, KAboutData::License_GPL,
-                       I18N_NOOP("(c) 1999-2005, The KDevelop developers"), "", "http://www.kdevelop.org");
+                       I18N_NOOP("(c) 1999-2006, The KDevelop developers"), "", "http://www.kdevelop.org");
   aboutData.addAuthor("Alexander Dymo", I18N_NOOP("Release coordinator, Overall improvements, Pascal support, C++ support, New File and Documentation parts"), "adymo@kdevelop.org");
   aboutData.addAuthor("Amilcar do Carmo Lucas", I18N_NOOP("Release coordinator, API documentation, Doxygen and autoproject patches"), "amilcar@ida.ing.tu-bs.de");
   aboutData.addAuthor("Bernd Gehrmann", I18N_NOOP("Initial idea, basic architecture, much initial source code"), "bernd@kdevelop.org");
@@ -73,7 +73,7 @@ int main(int argc, char *argv[])
   aboutData.addCredit("Yann Hodique", I18N_NOOP("Patches"), "Yann.Hodique@lifl.fr");
   aboutData.addCredit("Tobias Gl\303\244\303\237er" , I18N_NOOP("Documentation Finder,  qmake projectmanager patches, usability improvements, bugfixes ... "), "tobi.web@gmx.de");
   aboutData.addCredit("Andreas Koepfle" , I18N_NOOP("QMake project manager patches"), "koepfle@ti.uni-mannheim.de");
-  aboutData.addCredit("Sascha Cunz" , I18N_NOOP("Cleanup and bugfixes for qEditor, AutoMake and much other stuff"), "mail@sacu.de");
+  aboutData.addCredit("Sascha Cunz" , I18N_NOOP("Cleanup and bugfixes for qEditor, AutoMake and much other stuff"), "sascha@kdevelop.org");
   aboutData.addCredit("Robert Gruber" , I18N_NOOP("SnippetPart, debugger and usability patches"), "rgruber@users.sourceforge.net");
   aboutData.addCredit("Zoran Karavla", I18N_NOOP("Artwork for the Ruby language"), "webmaster@the-error.net", "http://the-error.net");
 
@@ -85,26 +85,26 @@ int main(int argc, char *argv[])
 
   KDevIDEExtension::init();
 
-  SplashScreen *splash = 0;
+  KDevSplashScreen *splash = 0;
   QString splashFile = locate("appdata", "pics/kdevelop-splash.png");
   if (!splashFile.isEmpty())
   {
     QPixmap pm;
     pm.load(splashFile);
-    splash = new SplashScreen( pm );
+    splash = new KDevSplashScreen( pm );
   }
-  
+
   app.processEvents();
 
   if (splash) splash->message( i18n( "Loading Settings" ) );
   TopLevel::getInstance()->loadSettings();
 
-  QObject::connect(PluginController::getInstance(), SIGNAL(loadingPlugin(const QString &)), 
+  QObject::connect(PluginController::getInstance(), SIGNAL(loadingPlugin(const QString &)),
     splash, SLOT(message(const QString &)));
   if (splash) splash->show();
-  
+
   PluginController::getInstance()->loadInitialPlugins();
-  
+
   Core::getInstance()->doEmitCoreInitialized();
 
   if (splash) splash->message( i18n( "Starting GUI" ) );
@@ -139,8 +139,8 @@ int main(int argc, char *argv[])
 	  PartController::getInstance()->editDocument( KURL(args->url(a)) );
       }
   }
-  
+
   kapp->dcopClient()->registerAs("kdevelop");
-  
+
   return app.exec();
 }
