@@ -23,6 +23,7 @@
 #include <qtabbar.h>
 #include <qtoolbutton.h>
 
+#include <kxmlguiclient.h>
 #include <kaboutdata.h>
 #include <kdeversion.h>
 #include <kapplication.h>
@@ -54,7 +55,7 @@
 #include "partcontroller.h"
 #include "kdevcore.h"
 #include "kdevpartcontroller.h"
-#include "partselectwidget.h"
+//#include "partselectwidget.h"
 #include "api.h"
 #include "core.h"
 #include "statusbar.h"
@@ -64,6 +65,7 @@
 #include "editorproxy.h"
 
 #include "toplevel.h"
+#include "multibuffer.h"
 #include "mainwindowshare.h"
 #include "newmainwindow.h"
 
@@ -108,7 +110,7 @@ NewMainWindow::NewMainWindow(QWidget *parent, const char *name, KMdi::MdiMode md
     m_raiseEditor->setWhatsThis(i18n("<b>Raise editor</b><p>Focuses the editor."));
 
 	KStdAction::configureToolbars( this, SLOT(configureToolbars()), actionCollection(), "set_configure_toolbars" );
-	
+
 	//@fixme why is this part of KDevMainWindow?
 //    previous_output_view = NULL;
 }
@@ -228,7 +230,20 @@ void NewMainWindow::tabContext(QWidget* widget,const QPoint & pos)
 		QWidget * top_widget = EditorProxy::getInstance()->topWidgetForPart( part );
 		if ( top_widget && top_widget->parentWidget() == widget)
 		{
-			if( KParts::ReadOnlyPart * ro_part = dynamic_cast<KParts::ReadOnlyPart*>(part))
+    		KParts::ReadOnlyPart * ro_part = 0;
+    		if ( MultiBuffer *multiBuffer =
+    		     dynamic_cast<MultiBuffer*>( top_widget ) )
+    		{
+        		if ( multiBuffer->numberOfBuffers() > 1 )
+            		ro_part = dynamic_cast<KParts::ReadOnlyPart*>(multiBuffer->activeBuffer());
+    		}
+
+    		if( !ro_part )
+    		{
+        		ro_part = dynamic_cast<KParts::ReadOnlyPart*>(part);
+    		}
+
+    		if( ro_part )
 			{
 				m_currentTabURL = ro_part->url();
 
@@ -491,6 +506,9 @@ void NewMainWindow::embedPartView(QWidget *view, const QString &name, const QStr
         if (tabWidget()->count() > 0)
             tabIndex = tabWidget()->currentPageIndex() + 1;
     addWindow(child, mdiFlags, tabIndex);
+
+    if ( mdiMode() == KMdi::ToplevelMode )
+        PartController::getInstance()->addManagedTopLevelWidget( child );
 }
 
 void NewMainWindow::embedSelectView(QWidget *view, const QString &name, const QString &toolTip)
@@ -701,6 +719,34 @@ void NewMainWindow::loadSettings() {
     applyMainWindowSettings(config, "Mainwindow");
 }
 
+void NewMainWindow::setCurrentDocumentCaption( const QString &caption )
+{
+    // Make sure we are in an applicable MDI mode
+    if ( mdiMode() == KMdi::TabPageMode
+         || mdiMode() == KMdi::IDEAlMode )
+    {
+        if ( KMdiChildView *view =
+            dynamic_cast<KMdiChildView *>( tabWidget()->currentPage() ) )
+        {
+            // Because setTabCaption() doesn't update the UI
+            // Oh, happy days, KMDI!
+            view->setCaption( caption );
+            // Because the context menu's depend on it nevertheless
+            view->setTabCaption( caption );
+        }
+    }
+    else
+    {
+        if ( activeWindow() )
+        {
+            // Because what KMDI means by an active window
+            // and what is normally meant are two very different
+            // things :(
+            if ( activeWindow()->isActiveWindow() )
+                activeWindow()->setCaption( caption );
+        }
+    }
+}
 
 void NewMainWindow::saveSettings()
 {
