@@ -377,34 +377,59 @@ void PartController::editDocumentInternal( const KURL & inputUrl, int lineNum,
 	// we don't trust KDE with designer files, let's handle it ourselves
 	if ( !m_openNextAsText && MimeType->is( "application/x-designer" ) )
 	{
-		QString DesignerSetting = config->readEntry( "DesignerSetting", "ExternalDesigner" );
-
-		if ( DesignerSetting == "EmbeddedKDevDesigner" )
+		QDomDocument* dom = API::getInstance()->projectDom();
+		if ( dom != 0 )
 		{
-			if ( KParts::ReadOnlyPart *designerPart = qtDesignerPart() )
+
+			// Short explanation for the following: 
+			// The global option specifies a fallback if the project
+			// has no setting or no project is open. However for Qt4
+			// projects we want to use ExternalDesigner in any case.
+			QString DefaultDesignerSetting = config->readEntry( "DesignerSetting", "ExternalDesigner" );
+
+			if ( DomUtil::readIntEntry( *dom, "/kdevcppsupport/qt/version", 3 ) == 4 )
+				DefaultDesignerSetting = "ExternalDesigner";
+
+			QString DesignerSetting = DomUtil::readEntry(*dom, "/kdevcppsupport/qt/designerintegration", DefaultDesignerSetting );
+
+			if ( DesignerSetting == "EmbeddedKDevDesigner" )
 			{
-				addHistoryEntry();
-				activatePart(designerPart);
-				designerPart->openURL(url);
-				return;
+				if ( KParts::ReadOnlyPart *designerPart = qtDesignerPart() )
+				{
+					addHistoryEntry();
+					activatePart(designerPart);
+					designerPart->openURL(url);
+					return;
+				}
+				else if ( KParts::Factory * KDevDesignerFactory = static_cast<KParts::Factory*>( KLibLoader::self()->factory( QFile::encodeName( "libkdevdesignerpart" ) ) ) )
+				{
+					KParts::ReadWritePart * kdevpart = static_cast<KParts::ReadWritePart*>( KDevDesignerFactory->createPart( TopLevel::getInstance()->main(), 0, 0, 0, "KParts::ReadWritePart"  ) );
+					kdevpart->openURL( url );
+					addHistoryEntry();
+					integratePart( kdevpart, url );
+					m_openRecentAction->addURL( url );
+					m_openRecentAction->saveEntries( kapp->config(), "RecentFiles" );
+					return;
+				}
 			}
-			else if ( KParts::Factory * KDevDesignerFactory = static_cast<KParts::Factory*>( KLibLoader::self()->factory( QFile::encodeName( "libkdevdesignerpart" ) ) ) )
+	
+			QString designerDesktopName;
+	
+			if ( DesignerSetting == "ExternalKDevDesigner" )
 			{
-				KParts::ReadWritePart * kdevpart = static_cast<KParts::ReadWritePart*>( KDevDesignerFactory->createPart( TopLevel::getInstance()->main(), 0, 0, 0, "KParts::ReadWritePart"  ) );
-				kdevpart->openURL( url );
-				addHistoryEntry();
-				integratePart( kdevpart, url );
-				m_openRecentAction->addURL( url );
-				m_openRecentAction->saveEntries( kapp->config(), "RecentFiles" );
-				return;
+				designerDesktopName = "kdevdesigner";
 			}
+			else
+			{
+				QString QtDir = DomUtil::readEntry(*dom, "/kdevcppsupport/qt/root");
+				if ( QtDir != QString::null )
+					designerDesktopName = QtDir+"/bin/";
+				designerDesktopName += "designer";
+			}
+	
+			KRun::run( designerDesktopName, url );
+			return;
 		}
-
-		QString designerDesktopName = "designer";
-		if ( DesignerSetting == "ExternalKDevDesigner" ) designerDesktopName = "kdevdesigner";
-
-		KRun::run( designerDesktopName, url );
-		return;
 	}
 
 	config->setGroup("General");
@@ -709,6 +734,9 @@ void PartController::integrateTextEditorPart(KTextEditor::Document* doc)
   if ( !doc ) return;
 
   connect( doc, SIGNAL(textChanged()), this, SLOT(textChanged()) );
+  connect( doc, SIGNAL(fileNameChanged()),
+    this, SLOT(slotDocumentUrlChanged()));
+
 
   if ( KTextEditor::View * view = dynamic_cast<KTextEditor::View*>( doc->widget() ) )
   {
@@ -871,8 +899,6 @@ bool PartController::closePart(KParts::Part *part)
 
     KURL url = ro_part->url();
 
-    TopLevel::getInstance()->main()->guiFactory()->removeClient( part );
-
     if (QWidget* w = EditorProxy::getInstance()->topWidgetForPart( part ) )
     {
         if ( MultiBuffer *multiBuffer = dynamic_cast<MultiBuffer*>( w ) )
@@ -891,6 +917,7 @@ bool PartController::closePart(KParts::Part *part)
                 _dirtyDocuments.remove( static_cast<KParts::ReadWritePart*>( ro_part ) );
                 emit closedFile( url );
 /*                kdDebug(9000) << "Deleting MultiBuffer Part" << endl;*/
+                TopLevel::getInstance()->main()->guiFactory()->removeClient( part );
                 delete part;
 /*                kdDebug(9000) << "DeleteLater Actual MultiBuffer" << endl;*/
                 multiBuffer->deleteLater();
@@ -900,6 +927,7 @@ bool PartController::closePart(KParts::Part *part)
             {
 /*                kdDebug(9000) << "Deleting MultiBuffer Part" << endl;*/
                 _dirtyDocuments.remove( static_cast<KParts::ReadWritePart*>( ro_part ) );
+                TopLevel::getInstance()->main()->guiFactory()->removeClient( part );
                 emit closedFile( url );
                 delete part;
                 // Switch to a remaining buffer
@@ -913,6 +941,7 @@ bool PartController::closePart(KParts::Part *part)
     }
     else if ( !ro_part->closeURL() )
         return false;
+    TopLevel::getInstance()->main()->guiFactory()->removeClient( part );
 
     _dirtyDocuments.remove( static_cast<KParts::ReadWritePart*>( ro_part ) );
     emit closedFile( url );
@@ -1758,4 +1787,21 @@ void PartController::gotoLastEditPos()
 	editDocument( m_lastEditPos.url, m_lastEditPos.pos.first, m_lastEditPos.pos.second );
 }
 
+void PartController::slotDocumentUrlChanged()
+{
+    QObject *obj = const_cast<QObject*>(sender());
+    KTextEditor::Document *doc = dynamic_cast<KTextEditor::Document*>( obj );
+    if (!doc)
+        return;
+
+    MultiBuffer *multiBuffer = dynamic_cast<MultiBuffer*>(
+        EditorProxy::getInstance()->findPartWidget( doc ));
+    if (!multiBuffer)
+        return;
+
+    multiBuffer->updateUrlForPart(doc, doc->url());
+    updatePartURL(doc);
+    emit partURLChanged(doc);
+}
+
 #include "partcontroller.moc"
