@@ -19,9 +19,7 @@
 #include "profileeditor.h"
 
 #include <qlayout.h>
-#include <qlineedit.h>
-#include <qlistbox.h>
-#include <qlistview.h>
+#include <klineedit.h>
 #include <qtextedit.h>
 #include <qpalette.h>
 
