@@ -43,11 +43,12 @@ class QDomDocument;
 #include "plugincontroller.h"
 #include "partcontroller.h"
 #include "codemodel.h"
-#include "partselectwidget.h"
+// #include "partselectwidget.h"
 #include "languageselectwidget.h"
 #include "generalinfowidget.h"
 #include "projectsession.h"
 #include "domutil.h"
+#include "settings.h"
 
 #include "projectmanager.h"
 
@@ -152,11 +153,6 @@ void ProjectManager::slotProjectOptions()
     GeneralInfoWidget *g = new GeneralInfoWidget(*API::getInstance()->projectDom(), box, "general informations widget");
     connect (&dlg, SIGNAL(okClicked()), g, SLOT(accept()));
 
-  QVBox *vbox = dlg.addVBoxPage( i18n("Plugins"), i18n("Plugins"), BarIcon( "kdf", KIcon::SizeMedium ) );
-  PartSelectWidget *w = new PartSelectWidget(*API::getInstance()->projectDom(), vbox, "part selection widget");
-  connect( &dlg, SIGNAL(okClicked()), w, SLOT(accept()) );
-  connect( w, SIGNAL(accepted()), this, SLOT(loadLocalParts()) );
-
   KConfig *config = kapp->config();
   config->setGroup("Project Settings Dialog");
   int height = config->readNumEntry( "Height", 600 );
@@ -206,11 +202,11 @@ void ProjectManager::loadDefaultProject()
 bool ProjectManager::loadProject(const KURL &projectURL)
 {
   KURL url = projectURL;
-  
+
   if (!url.isValid())
     return false;
 
-  if (url.isLocalFile()) 
+  if (url.isLocalFile())
   {
     QDir dir(url.path());
     url.setPath(dir.canonicalPath());
@@ -272,10 +268,10 @@ void ProjectManager::slotLoadProject( )
 	kapp->restoreOverrideCursor();
     return;
   }
-  
+
   TopLevel::getInstance()->statusBar()->message( i18n("Changing plugin profile...") );
   m_oldProfileName = PluginController::getInstance()->changeProfile(m_info->m_profileName);
-  
+
   TopLevel::getInstance()->statusBar()->message( i18n("Loading project plugins...") );
   loadLocalParts();
 
@@ -457,7 +453,8 @@ void ProjectManager::getGeneralInfo()
 //  m_info->m_profileName = getAttribute(generalEl, "profile");
   QDomElement el = generalEl.namedItem("profile").toElement();
   if (el.isNull())
-      m_info->m_profileName = profileByAttributes(m_info->m_language, m_info->m_keywords);
+//      m_info->m_profileName = profileByAttributes(m_info->m_language, m_info->m_keywords);
+      m_info->m_profileName = Settings::profileByAttributes(m_info->m_language, m_info->m_keywords);
   else
       m_info->m_profileName = el.firstChild().toText().data();
 }
@@ -614,34 +611,34 @@ bool ProjectManager::loadKDevelop2Project( const KURL & url )
     return loadProject( KURL(projectFile) );
 }
 
-QString ProjectManager::profileByAttributes(const QString &language, const QStringList &keywords)
-{
-    KConfig config(locate("data", "kdevelop/profiles/projectprofiles"));
-    config.setGroup(language);
-    
-    QStringList profileKeywords = QStringList::split("/", "Empty");
-    if (config.hasKey("Keywords"))
-        profileKeywords = config.readListEntry("Keywords");
-    
-    int idx = 0;
-    for (QStringList::const_iterator it = profileKeywords.constBegin();
-        it != profileKeywords.constEnd(); ++it)
-    {
-        if (keywords.contains(*it))
-        {
-            idx = profileKeywords.findIndex(*it);
-            break;
-        }
-    }
-    
-    QStringList profiles;
-    if (config.hasKey("Profiles"))
-    {
-        profiles = config.readListEntry("Profiles");
-        kdDebug() << "IDX: " << idx << "    PROFILE: " << profiles[idx] << endl;
-        return profiles[idx];
-    }
-    return "KDevelop";
-}
+// QString ProjectManager::profileByAttributes(const QString &language, const QStringList &keywords)
+// {
+//     KConfig config(locate("data", "kdevelop/profiles/projectprofiles"));
+//     config.setGroup(language);
+//
+//     QStringList profileKeywords = QStringList::split("/", "Empty");
+//     if (config.hasKey("Keywords"))
+//         profileKeywords = config.readListEntry("Keywords");
+//
+//     int idx = 0;
+//     for (QStringList::const_iterator it = profileKeywords.constBegin();
+//         it != profileKeywords.constEnd(); ++it)
+//     {
+//         if (keywords.contains(*it))
+//         {
+//             idx = profileKeywords.findIndex(*it);
+//             break;
+//         }
+//     }
+//
+//     QStringList profiles;
+//     if (config.hasKey("Profiles"))
+//     {
+//         profiles = config.readListEntry("Profiles");
+//         kdDebug() << "IDX: " << idx << "    PROFILE: " << profiles[idx] << endl;
+//         return profiles[idx];
+//     }
+//     return "KDevelop";
+// }
 
 #include "projectmanager.moc"
