@@ -264,7 +264,14 @@ void SimpleMainWindow::saveSettings( )
 }
 
 void SimpleMainWindow::setCurrentDocumentCaption( const QString &caption )
-{}
+{
+	if( !PartController::getInstance()->activePart() ) return;
+	
+	if (QWidget *widget = EditorProxy::getInstance()->topWidgetForPart(PartController::getInstance()->activePart()))
+	{
+		widget->setCaption(caption);
+	}
+}
 
 KMainWindow *SimpleMainWindow::main()
 {
@@ -389,7 +396,10 @@ void SimpleMainWindow::projectOpened()
 void SimpleMainWindow::slotPartURLChanged(KParts::ReadOnlyPart *part)
 {
     if (QWidget *widget = EditorProxy::getInstance()->topWidgetForPart(part))
+    {
+        kdDebug() << "new caption for widget: " << part->url().fileName() << endl;
         widget->setCaption(part->url().fileName());
+    }
         //do smth with caption: ro_part->url().fileName()
 }
 
